@@ -41,14 +41,14 @@ end
 function atk.secondary()
    ai.weapset( 2, true ) -- Usually seekers / ammo outfits are here
 end
-function atk.pointdefense()
+function atk.pointdefence()
    ai.weapset( 3, true ) -- Probably want to keep on most of the time
 end
 function atk.fighterbays()
    ai.weapset( 4, true ) -- Toggle to launch
 end
 function atk.fb_and_pd()
-   atk.pointdefense()
+   atk.pointdefence()
    atk.fighterbays()
 end
 function atk.turrets()
@@ -90,20 +90,20 @@ end
 
 --[[
 --Attempts to maintain a constant distance from nearby things
---This modulates the distance between the current pilot and its nearest neighbor
+--This modulates the distance between the current pilot and its nearest neighbour
 --]]
 function atk.keep_distance()
-   --anticipate this will be added to eliminate potentially silly behavior if it becomes a problem
+   --anticipate this will be added to eliminate potentially silly behaviour if it becomes a problem
    --local flight_offset = ai.drift_facing()
 
    --find nearest thing
-   local neighbor = ai.nearestpilot()
-   if not neighbor or not neighbor:exists() then
+   local neighbour = ai.nearestpilot()
+   if not neighbour or not neighbour:exists() then
       return
    end
 
    --find the distance based on the direction I'm travelling
-   local perp_distance = ai.flyby_dist(neighbor)
+   local perp_distance = ai.flyby_dist(neighbour)
    -- adjust my direction of flight to account for this
    -- if pilot is too close, turn away
    if perp_distance < 0 and perp_distance > -50 then
@@ -131,9 +131,9 @@ end
 -- Decides if zigzag is a good option
 --]]
 function atk.decide_zz( target, dist )
-   -- Some AI will not do fancy maneuvers
-   if mem.simplecombat then return false end
-   if target:flags("disabled") then return false end -- Don't be fance with disabled ships
+   -- Some AI will not do fancy manoeuvres
+   if mem.atk_skill <= 0.45+0.55*mem.rand then return false end
+   if target:disabled() then return false end -- Don't be fance with disabled ships
    -- The situation is the following: we're out of range, facing the target,
    -- going towards the target, and someone is shooting on us.
    local pilot  = ai.pilot()
@@ -145,7 +145,8 @@ function atk.decide_zz( target, dist )
    local d = d1-d2
 
    return ( (dist > range) and (ai.hasprojectile())
-           and (dir < math.rad(10)) and (dir > -math.rad(10)) and (d < math.rad(10)) and (d > -math.rad(10)) )
+      and (dir < math.rad(10)) and (dir > -math.rad(10))
+      and (d < math.rad(10)) and (d > -math.rad(10)) )
 end
 
 --[[
@@ -189,7 +190,7 @@ function atk.com_think( target, dokill )
    end
 
    -- Check to see if target is disabled
-   if not mem.atk_kill and target:flags("disabled") then
+   if not mem.atk_kill and target:disabled() then
       ai.poptask()
       return
    end
@@ -283,7 +284,7 @@ function atk.flyby( target, dist )
 end
 
 --[[
--- Attack Profile for a maneuverable ship engaging a maneuverable target
+-- Attack Profile for a manoeuvrable ship engaging a manoeuvrable target
 --
 --This is designed for fighters engaging other fighters
 --]]
@@ -343,7 +344,7 @@ end
 
 local function ___atk_g_ranged_dogfight( target, dist )
    local dir
-   if not mem.careful or dist < 3 * atk.primary_range() * mem.atk_approach then
+   if mem.atk_skill <= 0.45+0.55*mem.rand or dist < 3 * atk.primary_range() * mem.atk_approach then
       dir = ai.face(target) -- Normal face the target
    else
       dir = ai.careful_face(target) -- Careful method
