@@ -15,7 +15,6 @@ function __hoge( data ) -- internal in name only, or forward-declared local func
 
 -- Remark: the (sub)taskdata is passed as the (sub)task function argument
 --]]
-
 local atk = require "ai.core.attack.util"
 local fmt = require "format"
 local scans = require "ai.core.misc.scans"
@@ -40,8 +39,7 @@ end
 -- Brakes the ship
 --]]
 function brake ()
-   ai.brake()
-   if ai.isstopped() then
+   if ai.brake() then
       ai.stop()
       ai.poptask()
       return
@@ -54,8 +52,7 @@ end
 --]]
 -- luacheck: globals _subbrake (AI Task functions passed by name)
 function _subbrake ()
-   ai.brake()
-   if ai.isstopped() then
+   if ai.brake() then
       ai.stop()
       ai.popsubtask()
       return
@@ -91,16 +88,16 @@ local function __zigzag ( dir, angle )
    ai.accel()
 end
 local function __zigzag_run_decide( self, target )
-   -- Some AI will not do fancy maneuvers
-   if mem.simplecombat then return false end
+   -- Some AI will not do fancy manoeuvres
+   if mem.atk_skill <= 0.45+0.55*mem.rand then return false end
    -- Try to figure it out
-   local ss = self:stats()
-   local relspe = ss.speed_max/target:stats().speed_max
-   return ( ss.mass <= 400
-            and relspe <= 1.01
-            and ai.hasprojectile()
-            and (not ai.hasafterburner() or self:energy() < 10)
-          )
+   local relspe = self:speedMax() / target:speedMax()
+   return (
+      self:mass() <= 400
+      and relspe <= 1.01
+      and ai.hasprojectile()
+      and (not ai.hasafterburner() or self:energy() < 10)
+   )
 end
 
 
@@ -111,7 +108,7 @@ end
 function _attack_zigzag( target )
    target = atk.com_think( target )
    if target == nil then return end
-   if target:flags("disabled") then
+   if target:disabled() then
       ai.popsubtask()
       return
    end
@@ -129,7 +126,7 @@ function _attack_zigzag( target )
 
    -- Are we ready to shoot?
    local dist = ai.dist( target )
-   local range = ai.getweaprange(3)
+   local range = atk.primary_range()
    if dist < range then
       ai.popsubtask()
       return
@@ -144,7 +141,7 @@ end
 -- Goes to a target position without braking
 --]]
 function moveto_nobrake( target )
-   local dir      = ai.face( target, nil, true )
+   local dir   = ai.face( target, nil, true )
    __moveto_generic( target, dir )
 end
 
@@ -153,7 +150,7 @@ end
 -- Goes to a target position without braking
 --]]
 function moveto_nobrake_raw( target )
-   local dir      = ai.face( target )
+   local dir   = ai.face( target )
    __moveto_generic( target, dir )
 end
 
@@ -162,8 +159,8 @@ end
 -- Goes to a target position
 --]]
 function moveto( target )
-   local dir      = ai.face( target, nil, true )
-   local dist     = ai.dist( target )
+   local dir   = ai.face( target, nil, true )
+   local dist  = ai.dist( target )
 
    -- Handle finished
    if ai.isstopped() and dist < 10 then
@@ -179,6 +176,7 @@ function moveto( target )
 
    -- Need to start braking
    elseif dist < bdist then
+      ai.outfitOffAll()
       ai.pushsubtask("_subbrake")
    end
 end
@@ -189,31 +187,51 @@ end
 --]]
 -- luacheck: globals inspect_moveto (AI Task functions passed by name)
 function inspect_moveto( target )
-   local dir      = ai.face( target, nil, true )
+   local dir   = ai.face( target, nil, true )
    __moveto_generic( target, dir )
 end
 
+-- luacheck: globals inspect_attacker
+function inspect_attacker( target )
+   inspect_moveto( target )
+   -- Activate PD and deploy fighters
+   atk.fb_and_pd()
+end
+
+
+--[[
+-- Lunges towards the target always accelerating
+--]]
+function lunge( target )
+   if not target:exists() then
+      ai.poptask()
+      return
+   end
+   ai.aim( target )
+   ai.accel()
+end
+
 
 --[[
 -- Generic moveto function.
 --]]
 function __moveto_generic( target, dir )
-   local dist     = ai.dist( target )
-   local bdist    = 50
-
-   -- Need to get closer
-   if dir < math.rad(10) and dist > bdist then
-      ai.accel()
+   local dist  = ai.dist( target )
+   local bdist = 50
 
    -- Need to start braking
-   elseif dist < bdist then
+   if dist < bdist then
       ai.poptask()
+
+   -- Need to get closer
+   elseif dir < math.rad(10) and dist > bdist then
+      ai.accel()
    end
 end
 
 
 --[[
--- Follows it's target.
+-- Follows its target.
 --]]
 function follow( target )
    -- Will just float without a target to escort.
@@ -225,6 +243,9 @@ function follow( target )
    local dir   = ai.face(target)
    local dist  = ai.dist(target)
 
+   -- Stealth like whoever is being followed
+   ai.stealth( target:flags("stealth") )
+
    -- Must approach
    if dir < math.rad(10) and dist > 300 then
       ai.accel()
@@ -239,6 +260,9 @@ function follow_accurate( target )
       return
    end
 
+   -- Stealth like whoever is being followed
+   ai.stealth( target:flags("stealth") )
+
    local goal = ai.follow_accurate(target, mem.radius,
          mem.angle, mem.Kp, mem.Kd)
 
@@ -270,27 +294,40 @@ function follow_fleet ()
       end
 
    else -- Ship has a precise position in formation
-      if mem.app == nil then
-         mem.app = 2
-      end
 
       local angle, radius, method = table.unpack(mem.form_pos)
-      local goal  = ai.follow_accurate(leader, radius, angle, mem.Kp, mem.Kd, method) -- Standard controller
-      local dist  = ai.dist(goal)
+      local goal = ai.follow_accurate(leader, radius, angle, mem.Kp, mem.Kd, method) -- Standard controller
+      local dist = ai.dist(goal)
+      --local relvel = plt:vel():dist( leader:vel() )
 
-      if mem.app == 2 then
+      --if dist > 0 then
+         local dir = ai.face(goal)
+         if dir < math.rad(10) then  -- Must approach
+            ai.accel( (dist-50) / 200 )
+         end
+      --else
+      --   ai.face( leader:dir() )
+      --end
+
+      --[[ While the approach below is much more accurate when enabled, it
+      --   causes the ships to constantly do small corrections which can be
+      --   visually unpleasing. Disabling it gives more consistent results.
+      if mem._flw == nil then
+         mem._flw = 1
+      end
+      if mem._flw == 1 then
          local dir   = ai.face(goal)
-         if dist > 300 then
+         if dist > 30 then
             if dir < math.rad(10) then  -- Must approach
-               ai.accel()
+               ai.accel( dist / 200 - 0.5 )
             end
-         else  -- Toggle precise positioning controller
-            mem.app = 1
+         else
+            mem._flw = 0
          end
 
-      elseif mem.app == 1 then -- only small corrections to do
+      elseif mem._flw == 1 then -- only small corrections to do
          if dist > 300 then -- We're much too far away, we need to toggle large correction
-            mem.app = 2
+            mem._flw = 2
          else  -- Derivative-augmented controller
             local goal0 = ai.follow_accurate(leader, radius, angle, 2*mem.Kp, 10*mem.Kd, method)
             local dist0 = ai.dist(goal0)
@@ -300,19 +337,17 @@ function follow_fleet ()
                   ai.accel()
                end
             else  -- No need to approach anymore
-               mem.app = 0
+               mem._flw = 0
             end
          end
-
       else
-         ai.face(goal)
          if dist > 300 then   -- Must approach
-            mem.app = 1
-         else   -- Face forward
-            goal = plt:pos() + leader:vel()
-            ai.face(goal)
+            mem._flw = 1
+            return
          end
+         ai.face( leader:dir() )
       end
+      --]]
    end
 end
 
@@ -339,7 +374,7 @@ end
 -- luacheck: globals _hyp_approach_shoot (AI Task functions passed by name)
 function _hyp_approach_shoot( target )
    -- Shoot and approach
-   local enemy = ai.getenemy()
+   local enemy = atk.preferred_enemy()
    __shoot_turret( enemy )
    __hyp_approach( target )
 end
@@ -351,7 +386,7 @@ end
 
 -- luacheck: globals _landgo_shoot (AI Task functions passed by name)
 function _landgo_shoot ( planet )
-   local enemy = ai.getenemy()
+   local enemy = atk.preferred_enemy()
    __shoot_turret( enemy )
    __landgo( planet )
 end
@@ -368,14 +403,13 @@ function __choose_land_target ( target )
 
    -- Make sure target is valid
    if target == nil then
-      local landplanet = ai.landplanet()
-      if landplanet ~= nil then
-         target = landplanet
+      local landspob = ai.landspob( mem.land_friendly )
+      if landspob ~= nil then
+         target = landspob
 
       -- Bail out if no valid planet could be found.
       else
-         warn(fmt.f(_("Pilot '{plt}' tried to land with no landable assets!"),
-               {plt=ai.pilot():name()}))
+         warn(fmt.f(_("Pilot '{plt}' tried to land with no landable spob!"), {plt=ai.pilot()}))
          ai.poptask()
          return
       end
@@ -387,7 +421,7 @@ function __choose_land_target ( target )
    return target
 end
 
-function land ( target )
+function land( target )
    local planet = __choose_land_target ( target )
    ai.pushsubtask( "_landgo", planet )
 end
@@ -417,6 +451,7 @@ function __landgo ( planet )
 
    -- Need to start braking
    elseif dist < bdist then
+      ai.outfitOffAll()
       ai.pushsubtask( "_landland", planet )
       ai.pushsubtask( "_subbrake" )
    end
@@ -434,11 +469,18 @@ function _landland ( planet )
    end
 end
 
-
 --[[
 -- Attempts to run away from the target.
 --]]
 function runaway( target )
+   -- Fighters will fly back to the mothership and swap the runaway task for
+   -- the flyback task
+   if mem.carried and mem.mothership and mem.mothership:exists() then
+      ai.pilot():taskClear()
+      ai.pushtask( "flyback", true )
+      return
+   end
+
    -- Target must exist
    if not target or not target:exists() then
       ai.poptask()
@@ -446,8 +488,14 @@ function runaway( target )
    end
 
    -- See if there's a target to use when running
-   local t = ai.nearhyptarget()
-   local p = ai.nearestplanet()
+   local plt = ai.pilot()
+   local t, p
+   if not plt:flags("nojump") then
+      t = ai.nearhyptarget()
+   end
+   if not plt:flags("noland")  then
+      p = ai.nearestspob()
+   end
 
    if p == nil and t == nil then
       ai.pushsubtask( "_run_target" )
@@ -491,7 +539,7 @@ function _run_target( target )
    __run_target( target )
 end
 function __run_target( target )
-   local plt    = ai.pilot()
+   local plt = ai.pilot()
 
    -- Target must exist
    if not target or not target:exists() then
@@ -513,9 +561,15 @@ function __run_target( target )
       ai.accel()
    end
 
-   -- Afterburner handling.
-   if ai.hasafterburner() and plt:energy() > 10 then
-      ai.weapset( 8, true )
+   -- Outfits for running away
+   if mem._o then
+      if mem._o.afterburner and plt:energy() > 35 then
+         plt:outfitToggle( mem._o.afterburner, true )
+      elseif mem._o.blink_drive then
+         plt:outfitToggle( mem._o.blink_drive, true )
+      elseif mem._o.blink_engine then
+         plt:outfitToggle( mem._o.blink_engine, true )
+      end
    end
 
    return false
@@ -526,17 +580,15 @@ function __shoot_turret( target )
       return
    end
 
+   -- Point defence and Fighters
+   atk.fb_and_pd()
+
    -- Shoot the target
    ai.hostile(target)
    ai.settarget(target)
-   local dist = ai.dist(target)
    -- See if we have some turret to use
    if ai.hasturrets() then
-      if dist < ai.getweaprange(3) then
-         ai.weapset( 3 )
-         ai.shoot( true )
-         ai.weapset( 9 )
-      end
+      atk.turrets()
    end
 end
 
@@ -558,9 +610,11 @@ function _run_hyp( data )
    if jdist > bdist then
 
       local dozigzag = false
-      if enemy:exists() then
-         if __zigzag_run_decide( plt, enemy ) and jdist > 3*bdist then
-            dozigzag = true
+      if mem.atk_skill > 0.5+0.4*mem.rand then
+         if enemy:exists() then
+            if __zigzag_run_decide( plt, enemy ) and jdist > 3*bdist then
+               dozigzag = true
+            end
          end
       end
 
@@ -569,7 +623,7 @@ function _run_hyp( data )
          local dir = ai.dir(jp_pos)
          __zigzag(dir, math.rad(70))
       else
-         if jdist > 3*bdist and plt:stats().mass < 600 then
+         if jdist > 3*bdist and plt:mass() < 600 then
             jdir = ai.careful_face(jp_pos)
          else --Heavy ships should rush to jump point
             jdir = ai.face( jp_pos, nil, true )
@@ -579,20 +633,31 @@ function _run_hyp( data )
          end
       end
    else
+      ai.outfitOffAll()
       if ai.instantJump() then
          ai.pushsubtask( "_hyp_jump", jump )
       else
          ai.pushsubtask( "_hyp_jump", jump )
          ai.pushsubtask("_subbrake")
       end
+      return
    end
 
-   --Afterburner: activate while far away from jump
-   if ai.hasafterburner() and plt:energy() > 10 then
-      if jdist > 3 * bdist then
-         ai.weapset( 8, true )
-      else
-         ai.weapset( 8, false )
+   -- Hyperbolic blink drives have a distance of 2000
+   if mem._o then
+      if mem._o.afterburner then
+         local e = plt:energy()
+         -- Afterburner: activate while far away from jump
+         if jdist > 3 * bdist and e > 35 then
+            plt:outfitToggle( mem._o.afterburner, true )
+         elseif e < 10 then
+            plt:outfitToggle( mem._o.afterburner, false )
+         end
+      end
+      if mem._o.blink_drive and jdist > 500 + 3 * bdist then
+         plt:outfitToggle( mem._o.blink_drive, true )
+      elseif mem._o.blink_engine and jdist > 2000 + 3 * bdist then
+         plt:outfitToggle( mem._o.blink_engine, true )
       end
    end
 end
@@ -606,14 +671,15 @@ function _run_landgo( data )
    -- Shoot the target
    __shoot_turret( enemy )
 
+   local dir
    local dist     = ai.dist( pl_pos )
    local bdist    = ai.minbrakedist()
    local plt      = ai.pilot()
 
    if dist < bdist then -- Need to start braking
+      ai.outfitOffAll()
       ai.pushsubtask( "_landland", planet )
       ai.pushsubtask( "_subbrake" )
-      ai.weapset( 8, false ) -- Turn off afterburner just in case
       return -- Don't try to afterburn
 
    else
@@ -626,12 +692,11 @@ function _run_landgo( data )
 
       if dozigzag then
          -- Pilot is agile, but too slow to outrun the enemy: dodge
-         local dir = ai.dir(pl_pos)
+         dir = ai.dir(pl_pos)
          __zigzag(dir, math.rad(70))
       else
 
          -- 2 methods depending on mem.careful
-         local dir
          if not mem.careful or dist < 3*bdist then
             dir = ai.face( pl_pos )
          else
@@ -643,12 +708,21 @@ function _run_landgo( data )
       end
    end
 
-   --Afterburner
-   if ai.hasafterburner() and plt:energy() > 10 then
-      if dist > 3 * bdist then
-         ai.weapset( 8, true )
-      else
-         ai.weapset( 8, false )
+   -- Hyperbolic blink drives have a distance of 2000
+   if mem._o and dir < math.rad(25) then
+      if mem._o.afterburner then
+         local e = plt:energy()
+         -- Afterburner: activate while far away from jump
+         if dist > 3 * bdist and e > 35 then
+            plt:outfitToggle( mem._o.afterburner, true )
+         elseif e < 10 then
+            plt:outfitToggle( mem._o.afterburner, false )
+         end
+      end
+      if mem._o.blink_drive and dist > 500 + 3 * bdist then
+         plt:outfitToggle( mem._o.blink_drive, true )
+      elseif mem._o.blink_engine and dist > 2000 + 3 * bdist then
+         plt:outfitToggle( mem._o.blink_engine, true )
       end
    end
 end
@@ -677,24 +751,40 @@ function hyperspace( target )
          ai.poptask()
          return
       else
-         -- Push the new task
-         ai.pushsubtask("hyperspace", target)
+         -- Switch to a new task with the target
+         ai.poptask()
+         ai.pushtask("hyperspace", target)
          return
       end
    end
    mem.target_bias = vec2.newP( rnd.rnd()*target:radius()/2, rnd.angle() )
    ai.pushsubtask( "_hyp_approach", target )
+
+   -- Order followers to return if possible
+   local p = ai.pilot()
+   p:msg(p:followers(), "e_return", jump)
+end
+
+-- luacheck: globals hyperspace_follow (AI Task functions passed by name)
+function hyperspace_follow( target )
+   mem.target_bias = vec2.newP( rnd.rnd()*target:radius()/2, rnd.angle() )
+   ai.pushsubtask( "_hyp_approach_follow", target )
 end
 
 -- luacheck: globals _hyp_approach (AI Task functions passed by name)
 function _hyp_approach( target )
    __hyp_approach( target )
 end
-function __hyp_approach( target )
+-- luacheck: globals _hyp_approach_follow (AI Task functions passed by name)
+function _hyp_approach_follow( target )
+   __hyp_approach( target, "_hyp_jump_follow" )
+end
+function __hyp_approach( target, jumptsk )
    local dir
    local pos      = target:pos() + mem.target_bias
    local dist     = ai.dist( pos )
    local bdist    = ai.minbrakedist()
+   jumptsk = jumptsk or "_hyp_jump"
 
    -- 2 methods for dir
    if not mem.careful or dist < 3*bdist then
@@ -708,24 +798,51 @@ function __hyp_approach( target )
       ai.accel()
    -- Need to start braking
    elseif dist < bdist then
+      ai.outfitOffAll()
       if ai.instantJump() then
-         ai.pushsubtask("_hyp_jump", target)
+         ai.pushsubtask(jumptsk, target)
       else
-         ai.pushsubtask("_hyp_jump", target)
+         ai.pushsubtask(jumptsk, target)
          ai.pushsubtask("_subbrake")
       end
+      return
    end
 end
 
 -- luacheck: globals _hyp_jump (AI Task functions passed by name)
 function _hyp_jump ( jump )
-   if ai.hyperspace( jump ) == nil then
+   if ai.hyperspace( jump ) then
       local p = ai.pilot()
       p:msg(p:followers(), "hyperspace", jump)
    end
    ai.popsubtask() -- Keep the task even if succeeding in case pilot gets pushed away.
 end
 
+-- luacheck: globals _hyp_jump_follow (AI Task functions passed by name)
+function _hyp_jump_follow( jump )
+   local l = ai.pilot():leader()
+   if l and l:exists() then
+      -- Wait until leader is in hyperspace
+      if l:flags("jumpingout") then
+         _hyp_jump( jump )
+      else
+         if not ai.isstopped() then
+            -- Stop and wait just to get ready to hyperspace
+            ai.brake()
+         else
+            ai.stop()
+            ai.face( jump:angle() )
+            if not ai.canHyperspace() then
+               -- Drifted away or whatever, so pop and go back
+               ai.popsubtask()
+            end
+         end
+      end
+   else
+      _hyp_jump( jump )
+   end
+end
+
 
 --[[
 -- Boards the target
@@ -790,11 +907,8 @@ function _boardstop( target )
       end
    end
 
-   -- Just brake
-   ai.brake()
-
-   -- If stopped try again
-   if ai.isstopped() then
+   -- Just brake and end if stopped
+   if ai.brake() then
       ai.popsubtask()
    end
 end
@@ -811,8 +925,8 @@ function refuel( target )
       return
    end
 
-   -- See if finished refueling
-   if not ai.pilot():flags("refueling") then
+   -- See if finished refuelling
+   if not ai.pilot():flags("refuelling") then
       ai.poptask()
       return
    end
@@ -845,9 +959,9 @@ function _refuelstop( target )
    -- Set the target
    ai.settarget(target)
 
-   -- See if finished refueling
+   -- See if finished refuelling
    local p = ai.pilot()
-   if not p:flags("refueling") then
+   if not p:flags("refuelling") then
       p:comm(target, _("Finished fuel transfer."))
       ai.poptask()
 
@@ -861,11 +975,8 @@ function _refuelstop( target )
       return
    end
 
-   -- Just brake
-   ai.brake()
-
-   -- If stopped try again
-   if ai.isstopped() then
+   -- Just brake and end if stopped
+   if ai.brake() then
       ai.popsubtask()
    end
 end
@@ -874,12 +985,59 @@ end
 -- Mines an asteroid
 --]]
 -- luacheck: globals mine (AI Task functions passed by name)
-function mine( fieldNast )
-   ai.weapset( 1 )
-   local field     = fieldNast[1]
-   local ast       = fieldNast[2]
+function mine( ast )
+   if mem._o and mem._o.plasma_drill then
+      ai.pushsubtask("mine_drill", ast)
+   else
+      ai.pushsubtask("mine_shoot", ast)
+   end
+end
+-- luacheck: globals mine_drill (AI Task functions passed by name)
+function mine_drill( ast )
+   if not ast:exists() then
+      ai.poptask()
+      return
+   end
+
+   local pos = ast:pos()
+   local vel = ast:vel()
+   local mbd,bt = ai.minbrakedist()
+   -- Correct pos based on velocity and braking time
+   pos = pos + vel*bt
+   local dir = ai.iface(ast)
+   local mod = ai.dist(pos)
+
+   ai.setasterotarget( ast )
+   if dir < math.rad(10) and mod > mbd then
+      ai.accel()
+   elseif mod < mbd then
+      ai.outfitOffAll()
+      ai.pushsubtask( "mine_drill_brake", ast )
+   end
+end
+-- luacheck: globals mine_drill_brake (AI Task functions passed by name)
+function mine_drill_brake( ast )
+   if ai.isstopped() then
+      ai.popsubtask()
+      return
+   end
+   if not ast:exists() then
+      ai.poptask()
+      return
+   end
+   ai.brake()
+   ai.setasterotarget( ast )
+   ai.pilot():outfitToggle( mem._o.plasma_drill, true )
+end
+-- luacheck: globals mine_shoot (AI Task functions passed by name)
+function mine_shoot( ast )
+   if not ast:exists() then
+      ai.poptask()
+      return
+   end
+
    local p         = ai.pilot()
-   local wrange    = ai.getweaprange(nil, 0)
+   local wrange    = ai.getweaprangemin( atk.PRIMARY )
    local erange    = 100
    local trange    = math.min( math.max( erange, wrange * 3 / 4 ), wrange )
    local mbd       = ai.minbrakedist()
@@ -892,10 +1050,10 @@ function mine( fieldNast )
       return
    end
 
-   ai.setasterotarget( field, ast )
-
-   local target, vel = system.asteroidPos( field, ast )
+   ai.setasterotarget( ast )
 
+   local target = ast:pos()
+   local vel = ast:vel()
    local _dist, angle = vec2.polar( p:pos() - target )
 
    -- First task : place the ship close to the asteroid
@@ -912,17 +1070,19 @@ function mine( fieldNast )
    local relvel = vec2.add( p:vel(), vec2.mul(vel,-1) ):mod()
 
    if relpos < wrange and relvel < 10 then
-      ai.pushsubtask("_killasteroid", fieldNast )
+      ai.pushsubtask("_killasteroid", ast )
    end
 end
 
 -- luacheck: globals _killasteroid (AI Task functions passed by name)
-function _killasteroid( fieldNast )
-   local field     = fieldNast[1]
-   local ast       = fieldNast[2]
-   local wrange    = ai.getweaprange()
+function _killasteroid( ast )
+   if not ast:exists() then
+      ai.poptask()
+      return
+   end
+   local wrange    = ai.getweaprangemin( atk.PRIMARY )
 
-   local target = system.asteroidPos( field, ast )
+   local target = ast:pos()
    local dir  = ai.face(target)
 
     -- See if there's a gatherable; if so, pop this task and gather instead
@@ -941,11 +1101,11 @@ function _killasteroid( fieldNast )
 
    -- Second task : destroy it
    if dir < math.rad(8) then
-      ai.weapset( 1 )
-      ai.shoot()
-      ai.shoot(true)
+      -- TODO really use all weapon sets?
+      atk.primary()
+      atk.secondary()
    end
-   if system.asteroidDestroyed( field, ast ) then
+   if not ast:exists() then
       ai.poptask()
       -- Last task : gather
       ai.pushtask("gather")
@@ -1024,7 +1184,9 @@ end
 --]]
 -- luacheck: globals loiter (AI Task functions passed by name)
 function loiter( target )
-   local dir   = ai.face( target, nil, true )
+   -- So this makes it that when there are a lot of close waypoints, the pilot
+   -- is waggling a lot, by not correcting we get smoother motion
+   local dir   = ai.face( target, nil, mem.loiter_compensate_vel )
    local dist  = ai.dist( target )
    if dist < 200 then
       ai.poptask()
@@ -1037,7 +1199,7 @@ end
 -- Last vertex, so poptask when at brakedistance
 -- luacheck: globals loiter_last (AI Task functions passed by name)
 function loiter_last( target )
-   local dir   = ai.face( target, nil, true )
+   local dir   = ai.face( target, nil, mem.loiter_compensate_vel )
    local dist  = ai.dist( target )
    local bdist = ai.minbrakedist()
    if dist < bdist then
@@ -1060,8 +1222,7 @@ end
 
 
 function stealth( _target )
-   ai.brake()
-   if ai.isstopped() then
+   if ai.brake() then
       ai.stop()
    end
    -- TODO something to try to get them to restealth if failed, maybe move around?
@@ -1106,7 +1267,7 @@ function ambush_stalk( target )
    local dist  = ai.dist(target)
 
    -- Must approach
-   local range = ai.getweaprange( 3 )
+   local range = atk.primary_range()
    if dist < range * mem.atk_aim then
       -- Go for the kill!
       ai.pushtask( "attack", target )
