@@ -1,2 +1,2 @@
 local nebu_img = require "bkg.lib.nebula_image"
-nebu_img.init( "ngc-2440-2.webp" )
+nebu_img.init( "ngc-2440-2" )
