@@ -12,7 +12,7 @@ local background_default = background
 function background ()
    -- Scale factor that controls computation cost. As this shader is really
    -- really expensive, we can't compute it at full resolution
-   sf = naev.conf().nebu_scale
+   sf = bgshaders.scale_factor_default()
 
    -- Initialize shader
    shader = love_shaders.windy{ strength=sf, density=0.7 }
@@ -20,13 +20,17 @@ function background ()
 
    -- Default nebula background
    background_default()
+
+   -- Ambient light is coloured now
+   gfx.lightAmbient( 0.2, 0.6, 0.9, 0.2, 1.2 )
+   gfx.lightIntensity( 0.8 * gfx.lightIntensityGet() )
 end
 
 function renderfg( dt )
    -- Get camera properties
-   local x, y = camera.get():get()
-   local z = camera.getZoom()
-   shader:send( "u_camera", x*0.5/sf, -y*0.5/sf, z )
+   local x, y, z = camera.get()
+   local m = 0.5
+   shader:send( "u_camera", x*m/sf, y*m/sf, (1-m)+m*z )
 
    swind:render( dt, {0.2, 0.6, 0.9, 0.8} )
 end
