@@ -2,10 +2,10 @@
 <?xml version='1.0' encoding='utf8'?>
 <event name="Chapter 1">
  <unique />
- <location>enter</location>
+ <location>load</location>
  <chance>100</chance>
  <chapter>0</chapter>
- <priority>0</priority>
+ <priority>99</priority>
 </event>
 --]]
 --[[
@@ -20,6 +20,7 @@ local textoverlay = require "textoverlay"
 local pp_shaders = require "pp_shaders"
 local lmusic = require "lmusic"
 local luaspfx = require "luaspfx"
+local cinema = require "cinema"
 
 local diff_progress1 = "hypergates_1"
 local diff_progress2 = "hypergates_2"
@@ -36,16 +37,32 @@ local hypergate_list = {
 }
 
 function create ()
+   hook.enter( "enter" )
+end
+
+local claimed = false
+local done = false
+function enter ()
+   if done then return end
+
    -- Set up some variables
-   local has_license = diff.isApplied("heavy_combat_vessel_license") or (player.outfitNum("Heavy Combat Vessel License") > 0)
+   local has_licence = diff.isApplied("heavy_combat_vessel_licence") or (player.outfitNum("Heavy Combat Vessel Licence") > 0)
    local traded_total = var.peek("hypconst_traded_total") or 0
 
+   local explored = 0
+   for k,s in ipairs(system.getAll()) do
+      if s:known() then
+         explored = explored + 1
+      end
+   end
+
    -- Compute some sort of progress value
    local progress = traded_total / 2000 -- Would need 2000 ore delivered to trigger the change by this itself
          + #player.misnDoneList() / 40 -- Needs 40 missions to complete by itself
          + player.wealth() / 50e6 -- Needs 50 million by themselves to trigger event
-   -- Finally getting the heavy weapon or vessel license permission gives a large
-   if has_license then
+         + explored / 300 -- Needs 300 known systems
+   -- Finally getting the heavy weapon or vessel licence permission gives a large
+   if has_licence then
       progress = progress + 0.4
    end
 
@@ -54,12 +71,14 @@ function create ()
       -- Make event happen when player is not in any system with a hypergate
       for k,v in ipairs(system.cur():spobs()) do
          if v:tags().hypergate then
-            evt.finish(false)
+            return false
          end
       end
 
       -- Make sure system isn't claimed, but we don't claim it
-      if not naev.claimTest( system.cur() ) then evt.finish(false) end
+      if not naev.claimTest( system.cur() ) then
+         return false
+      end
 
       -- Sort the hypergates by player standing
       table.sort( hypergate_list, function ( a, b )
@@ -69,12 +88,15 @@ function create ()
       end )
 
       -- Let us claim the systems
-      local claimsys = {}
-      for k,h in ipairs(hypergate_list) do
-         table.insert( claimsys, h:system() )
-      end
-      if not evt.claim( claimsys ) then
-         evt.finish(false)
+      if not claimed then
+         local claimsys = {}
+         for k,h in ipairs(hypergate_list) do
+            table.insert( claimsys, h:system() )
+         end
+         if not evt.claim( claimsys ) then
+            return false
+         end
+         claimed = true
       end
 
       hook.safe( "cutscene_start" )
@@ -87,8 +109,7 @@ function create ()
 
    end
 
-   -- Finish the event, until next time :)
-   evt.finish(false)
+   -- Until next time :)
 end
 
 local function setHide( state )
@@ -148,7 +169,7 @@ function foreground ()
 
       if fg.text then
          lg.setColour( 1, 1, 1, fg.alpha )
-         lg.printf( fg.text, fg.font, fg.x, fg.y, 0.6*nw, "center" )
+         lg.printf( fg.text, fg.font, fg.x, fg.y, 0.6*nw, "centre" )
       end
    end
 end
@@ -231,7 +252,7 @@ local function getFactionStuff( fct )
             return "Sirius Preacher"
          end
       end
-      tester_broadcast = _("For Sirichana!")
+      tester_broadcast = _("For the Sirichana!")
       boss_broadcast = _("Starting ritual!")
    elseif fct == "Soromid" then
       bossship = "Soromid Arx"
@@ -275,7 +296,7 @@ function cutscene_start ()
 
    -- TODO better music
    music.stop(true)
-   lmusic.play( "snd/music/empire2.ogg" )
+   lmusic.play( "snd/music/empire2" )
 end
 
 -- Set up the cutscene stuff
@@ -283,7 +304,7 @@ local origsys, boss, tester, tester_broadcast, boss_broadcast
 function cutscene_main0 ()
    fg.alpha_vel = 2 -- Back to fast transitions
 
-   player.cinematics( true )
+   cinema.on()
    player.canDiscover( false )
    setHide( true )
 
@@ -345,7 +366,7 @@ local countdown, countdown_sfx
 function cutscene_main2 ()
    boss:broadcast( boss_broadcast )
    countdown = 5
-   countdown_sfx = audio.newSource( "snd/sounds/hypergate_turnon.ogg" )
+   countdown_sfx = audio.newSource( "snd/sounds/hypergate_turnon" )
    hook.timer( 4, "cutscene_main3" )
    hook.timer( 5+4-6.5, "cutscene_main_sfx" )
 end
@@ -577,7 +598,7 @@ function cutscene_nebu ()
    fg_setup() -- Remove text
 
    -- TODO omnious music and "ghost" ships
-   lmusic.play( "snd/sounds/loops/alienplanet.ogg" )
+   lmusic.play( "snd/sounds/loops/alienplanet" )
 
    hook.timer( 4.3, "fadeout" )
    hook.timer( 5, "cutscene_nebu_fade" )
@@ -591,10 +612,11 @@ function cutscene_nebu_fade ()
    lmusic.stop()
 
    -- Return to system and restore camera
+   done = true -- To stop the enter hook from rerunning
    player.teleport( origsys, false, true )
    camera.set( nil, true )
    camera.setZoom() -- Reset zoom
-   player.cinematics( false )
+   cinema.off()
    fadein()
    hook.timer( 2, "cutscene_cleanup" )
 end
@@ -610,7 +632,7 @@ function cutscene_cleanup ()
    textoverlay.init( _("CHAPTER 1"), _("The Hypergates Awaken") )
 
    -- TODO different sound than just discovery?
-   sfx = audio.newSource( 'snd/sounds/jingles/victory.ogg' )
+   sfx = audio.newSource( 'snd/sounds/jingles/victory' )
    sfx:play()
 
    -- Initialize fleet capacity
