@@ -40,6 +40,7 @@ local pir = require "common.pirate"
 local vn = require 'vn'
 local lf = require "love.filesystem"
 local lmisn = require "lmisn"
+local th = require "common.treasure_hunt"
 
 local badevent, goodevent, specialevent, neutralevent, derelict_msg -- forward-declared functions
 local derelict -- Non-persistent state
@@ -79,12 +80,14 @@ function create ()
       local weights = 0
       for _k,sp in ipairs(special_list) do
          weights = weights + sp.weight
-         sp.chance = weights
+         sp._weighted = weights
       end
       local r = rnd.rnd()
       for _k,sp in ipairs(special_list) do
-         if r < sp.chance / weights then
-            dospecial = sp
+         if r < sp._weighted / weights then
+            if rnd.rnd() < (sp.chance or 1) then
+               dospecial = sp
+            end
             break
          end
       end
@@ -109,20 +112,25 @@ function create ()
       dship = dospecial.ship
    end
    if not dship then
-      local r = rnd.rnd()
-      if r < 0.2 then
-         dship = "Llama"
-      elseif r < 0.3 then
-         dship = "Hyena"
-      elseif r < 0.5 then
-         dship = "Koala"
-      elseif r < 0.7 then
-         dship = "Quicksilver"
-      elseif r < 0.9 then
-         dship = "Mule"
-      else
-         dship = "Gawain"
+      local ships = {
+         'Hyena', 'Shark', 'Gawain', 'Llama',
+         'Koala', 'Quicksilver',
+         'Mule', 'Rhino',
+      }
+      local prs = system.cur():presences()
+      if prs["Frontier"] or prs["FLF"] then
+         ships = tmerge( ships, { 'Tristan', 'Bedivere' })
       end
+      if prs["Sirius"] then
+         table.insert( ships, "Schroedinger" )
+      end
+      if prs["Dvaered"] or prs["Goddard"] then
+         table.insert( ships, 'Ancestor' )
+      end
+      if prs["Dvaered"] then
+         table.insert( ships, 'Vendetta' )
+      end
+      dship = ships[ rnd.rnd( 1, #ships ) ]
    end
 
    -- Create the derelict.
@@ -130,8 +138,10 @@ function create ()
    local pos   = vec2.newP( dist, rnd.angle() )
    derelict    = pilot.add(dship, "Derelict", pos, p_("ship", "Derelict"), {ai="dummy", naked=true})
    derelict:outfitRm( "cores" ) -- Must be not-space worthy
+   derelict:setHealth( 10+40*rnd.rnd(), 0 )
    derelict:setDisable()
    derelict:intrinsicSet( "ew_hide", 300 ) -- Much more visible
+   derelict:intrinsicSet( "ew_signature", 300 ) -- Derelicts are obvious on the map either way, and we want to board on double click
    hook.pilot(derelict, "board", "board")
    hook.pilot(derelict, "death", "destroyevent")
    hook.jumpout("destroyevent")
@@ -152,19 +162,6 @@ function derelict_msg( title, text, log )
    der.addMiscLog( log )
 end
 
-local function islucky ()
-   local pp = player.pilot()
-   if pp:ship():tags().lucky then
-      return true
-   end
-   for k,o in ipairs(pp:outfitsList("all")) do
-      if o:tags().lucky then
-         return true
-      end
-   end
-   return false
-end
-
 function board()
    player.unboard()
 
@@ -175,7 +172,7 @@ function board()
 
    -- Roll for events
    local neuprob, goodprob
-   if islucky() then
+   if lmisn.is_lucky() then
       goodprob = 0.75
       neuprob = 0.95
    else
@@ -289,8 +286,11 @@ function goodevent()
 
    local goodevent_list = {
       function ()
-         derelict_msg( gtitle, _([[The derelict appears deserted, its passengers long gone. However, they seem to have left behind a small amount of credit chips in their hurry to leave! You decide to help yourself to them and leave the derelict.]]), fmt.f(_([[You found a derelict in {sys}, it was empty but for some scattered credit chips. Lucky you!]]), {sys=system.cur()}) )
-         player.pay( rnd.rnd(5e3,30e3) )
+         local reward = rnd.rnd(5e3,55e3)
+         derelict_msg( gtitle, fmt.f(_([[The derelict appears deserted, its passengers long gone. However, they seem to have left behind a small amount of credit chips in their hurry to leave! You decide to help yourself to the #g{reward}#0 and leave the derelict.]]), {reward=fmt.credits(reward)}),
+         fmt.f(_([[You found a derelict in {sys}, it was empty but for some scattered credit chips. Lucky you!]]), {sys=system.cur()}) )
+         player.pay( reward )
+         vn.na( fmt.reward( reward ) )
       end,
    }
 
@@ -391,7 +391,7 @@ function goodevent()
       end )
    end
 
-   -- If the player has little fuel left allow for refueling
+   -- If the player has little fuel left allow for refuelling
    local pp = player.pilot()
    local stats = pp:stats()
    if stats.fuel < 2*stats.fuel_consumption then
@@ -405,11 +405,23 @@ function goodevent()
    local armour, shield = pp:health()
    if armour < 50 and stats.armour_regen <= 0 then
       table.insert( goodevent_list, function ()
-         derelict_msg(gtitle, fmt.f(_([[The derelict is deserted and stripped of everything of value, however, you notice that the ship hull is in very good shape. In fact, it is rather suspicious that a ship in such good repair became a derelict. Hushing {shipai}, your ship AI, and without thinking too deeply about it you strip some of the hull components and are able to repair your own ship's armour.]]), {shipai=tut.ainame()}), fmt.f(_([[The hull of a derelict you found in {sys} provided you with the resources to repair your own, very useful in the circumstances!]]), {sys=system.cur()}))
+         derelict_msg(gtitle, fmt.f(_([[The derelict is deserted and stripped of everything of value, however, you notice that the ship hull is in very good shape. In fact, it is rather suspicious that a ship in such good repair became a derelict. Hushing {shipai}, your ship AI, and without thinking too deeply about it, you strip some of the hull components and are able to repair your own ship's armour.]]), {shipai=tut.ainame()}), fmt.f(_([[The hull of a derelict you found in {sys} provided you with the resources to repair your own, very useful in the circumstances!]]), {sys=system.cur()}))
          pp:setHealth( 100, shield )
       end )
    end
 
+   -- See if there can be a treasure hunt map
+   if th.maps_owned() < 3 then
+      -- Make sure to generate it first
+      local data = th.create_treasure_hunt( nil, 10 )
+      if data then
+         table.insert( goodevent_list, function ()
+            derelict_msg(gtitle, _([[You scour the deserted ship, which has been mainly picked clean by others, and when you are about to give up and turn back, you find a small map tucked in between some beams. Probably everyone missed it because it doesn't show up on scans. Looks it leads to someone's cache. Might be worth checking out!]]), fmt.f(_([[You obtained a treasure map on a derelict you found in the {sys} system.]]), {sys=system.cur()}))
+            th.give_map_from( data )
+         end )
+      end
+   end
+
    -- Run random good event
    goodevent_list[ rnd.rnd(1,#goodevent_list) ]()
    destroyevent()
@@ -517,6 +529,7 @@ function badevent()
                local dist = 800 + 200 * ship.get(v):size()
                local p = pilot.add( v, "Marauder", pos + vec2.newP( dist + rnd.rnd()*0.5*dist, rnd.angle() ) )
                p:setHostile( true ) -- Should naturally attack the player
+               p:memory().capturable = true -- Let the player capture them
                table.insert( pirates, p )
                if not leader then
                   leader = p
