@@ -1,10 +1,8 @@
 --[[
 <?xml version='1.0' encoding='utf8'?>
 <event name="System Tour">
- <trigger>none</trigger>
+ <location>none</location>
  <chance>0</chance>
- <flags>
- </flags>
 </event>
 --]]
 --[[
@@ -13,7 +11,6 @@
 -- naev.eventStart("System Tour")
 --]]
 local systems, idx
--- luacheck: globals screenshot teleport (Hook functions passed by name)
 
 function create()
    player.pilot():setInvincible()
@@ -29,9 +26,11 @@ function teleport()
 end
 
 function screenshot()
-   player.screenshot()
+   --player.screenshot()
    idx = idx + 1
    if systems[idx] ~= nil then
       hook.safe("teleport")
+   else
+      evt.finish()
    end
 end
