@@ -39,9 +39,10 @@ local function spawn_fleet( pos )
       local leader = plts[1]
       local p = pilot.add( s, "Proteron", pos, nil, {ai="guard"} )
       local aimem = p:memory()
-      aimem.enemyclose    = 10e3
-      aimem.guarddodist   = 10e3
+      aimem.enemyclose  = 10e3
+      aimem.guarddodist = 10e3
       aimem.guardreturndist = 15e3
+      aimem.capturable  = true
       if leader then
          p:setLeader( leader )
       end
@@ -71,6 +72,7 @@ function create ()
    hook.land("cleanup")
 end
 
+local timer = 0
 function heartbeat( proteron_blockade )
    -- If not hostile, ignore
    if not faction.get("Proteron"):areEnemies( faction.player() ) then
@@ -79,14 +81,24 @@ function heartbeat( proteron_blockade )
 
    -- Have the first ship that sees the player broadcast
    local pp = player.pilot()
+   local spotted = false
    for k,p in ipairs(proteron_blockade) do
-      if p:inrange( pp ) then
+      if p:inrange( pp ) and p:flags("combat") then
+         spotted = true
+         if timer < 3 then
+            timer = timer + 1
+            break
+         end
          p:broadcast( _("Unknown vessel trying to breach blockade. All ships engage!"), true)
          return
       end
    end
 
-   hook.timer( 0.5, "heartbeat", proteron_blockade )
+   if not spotted then
+      timer = 0
+   end
+
+   hook.timer( 1, "heartbeat", proteron_blockade )
 end
 
 function cleanup ()
