@@ -29,13 +29,15 @@ function create ()
 
    -- Add space mines
    local L = lanes.get( sysfct, "non-hostile" )
-   for i = 1,rnd.rnd(10,30) do
+   for i = 1,math.max(10,math.floor(1e-6*csys:radius()^2)) do
       -- The sqrt here makes it so the samples are uniform in Euclidean coordinates
-      local rad = system.cur():radius()*0.9*math.sqrt(rnd.rnd())
+      local rad = csys:radius()*0.95*math.sqrt(rnd.rnd())
       local pos = careful.getSafePointL( L, nil, vec2.new(), rad, 2e3, 2e3, 2e3 )
       if pos then
          sm( pos, nil, sysfct, {
+            duration = math.huge,
             hostile = true,
+            primed = 0, -- Already primed
          } )
       end
    end
