@@ -33,7 +33,7 @@ local fw = require "common.frontier_war"
 local lmisn = require "lmisn"
 local fmt = require "format"
 local pir = require "common.pirate"
-local ai_setup = require "ai.core.setup"
+local equipopt = require "equipopt"
 
 -- Mission constants
 local destpla1, destsys1 = spob.getS("Ginni")
@@ -49,7 +49,7 @@ local meet_text1 = _([[After Tam boards the Goddard, you wait for about half a p
 function create()
    -- The mission should not appear just after the FLF destruction
    if not (var.peek("invasion_time") == nil or
-           time.get() >= time.fromnumber(var.peek("invasion_time")) + time.new(0, 20, 0)) then
+         time.get() >= time.fromnumber(var.peek("invasion_time")) + time.new(0, 20, 0)) then
       misn.finish(false)
    end
 
@@ -148,12 +148,12 @@ function enter()
 end
 
 function testPlayerSpeed()
-  local stats = player.pilot():stats()
-  local playershipspeed = stats.speed_max
-  if playershipspeed < 300 then
+   local stats = player.pilot():stats()
+   local playershipspeed = stats.speed_max
+   if playershipspeed < 300 then
       tk.msg(_("Your ship is too slow"), _("Did you really expect to keep up with Major Tam with your current ship?"))
       misn.finish(false)
-  end
+   end
 end
 
 function explain_battle()
@@ -178,19 +178,26 @@ function spawnTam( origin )
    majorTam:setVisplayer()
    majorTam:setFaction( fw.fct_dhc() )
 
-   -- TODO switch to equipopt
-   majorTam:outfitAdd("S&K Light Combat Plating")
-   majorTam:outfitAdd("Milspec Orion 3701 Core System")
-   majorTam:outfitAdd("Tricon Zephyr II Engine")
-   majorTam:outfitAdd("Unicorp Light Afterburner")
-   --majorTam:outfitAdd("Solar Panel")
-   majorTam:outfitAdd("Vulcan Gun",3)
-   majorTam:outfitAdd("Gauss Gun",3)
-   majorTam:setHealth(100,100)
-   majorTam:setEnergy(100)
+   equipopt.dvaered( majorTam, {
+      cores = {
+         hull = "S&K Skirmish Plating",
+         hull_secondary = "S&K Skirmish Plating",
+         systems = "Milspec Orion 2301 Core System",
+         systems_secondary = "Milspec Orion 2301 Core System",
+         engines = "Tricon Zephyr Engine",
+         engines_secondary = "Tricon Zephyr Engine",
+      },
+      prefer = {
+         ["Gauss Gun"] = 100,
+         ["Unicorp Light Afterburner"] = 100,
+      },
+      move = 0,
+      max_same_weap = 10,
+      rnd = 0, -- Consistent
+   } )
    majorTam:setFuel(true)
-   majorTam:cargoRm( "all" )
-   ai_setup.setup(majorTam)
+
+   assert( majorTam:fuel() > 0 )
 
    mem.dyingTam = hook.pilot(majorTam, "death", "tamDied")
 end
@@ -247,7 +254,10 @@ function land() -- The player is only allowed to land on special occasions
    elseif mem.stage == 8 then
       shiplog.create( "dvaered_military", _("Dvaered Military Coordination"), _("Dvaered") )
       shiplog.append( "dvaered_military", _("Major Tam, from the Space Force Headquarters of Dvaered High Command (DHC) has employed you in the framework of the military coordination. One of the Warlords he was trying to pay a visit to, Lord Battleaddict, has tried to kill him twice, with help of his second in command, Colonel Hamelsen. It looks like trying to coordinate Dvaered warlords is a really dangerous job.") )
-      tk.msg(_("Thank you, citizen"), fmt.f(_([[As you land, Major Tam greets you at the spaceport. "After the losses they suffered today, I doubt those mercenaries will come after me again anytime soon. I need to report back at the Dvaer High Command station in Dvaer, and I no longer need an escort. Oh, and, err... about the payment, I am afraid there is a little setback..." You start to fear he will try to stiff you on the payment, but he continues: "I don't know why, but the High Command has not credited the payment account yet... Well do you know what we are going to do? I will give you a set of Gauss Guns worth {credits}! One always needs Gauss Guns, no?"]]), {credits=fmt.credits(fw.credits_00)}))
+      tk.msg(_("Thank you, citizen"), fmt.f(_([[As you land, Major Tam greets you at the spaceport. "After the losses they suffered today, I doubt those mercenaries will come after me again anytime soon. I need to report back at the Dvaer High Command station in Dvaer, and I no longer need an escort. Oh, and, err... about the payment, I am afraid there is a little setback..." You start to fear he will try to stiff you on the payment, but he continues: "I don't know why, but the High Command has not credited the payment account yet... Well do you know what we are going to do? I will give you {rew}! One always needs Gauss Guns, no?"]]), {
+         rew=fmt.f("#o".._("a set of Gauss Guns worth {credits}").."#0",
+            {credits=fmt.credits(fw.credits_00)})
+      }))
 
       -- Major Tam gives Gauss Guns instead of credits, because Major Tam is a freak.
       mem.GGprice = outfit.get("Gauss Gun"):price()
@@ -365,20 +375,28 @@ function hamelsenAmbush()
    hamelsen = pilot.add( "Shark", fwarlords, pos, _("Colonel Hamelsen"), {ai="baddie_norun", naked=true} )
 
    -- Nice outfits for Colonel Hamelsen (the Hellburner is her life insurance)
-   -- TODO switch to equipopt
-   hamelsen:outfitAdd("S&K Ultralight Combat Plating")
-   hamelsen:outfitAdd("Milspec Orion 2301 Core System")
-   hamelsen:outfitAdd("Tricon Zephyr Engine")
-   hamelsen:outfitAdd("Hellburner")
-   hamelsen:outfitAdd("Milspec Impacto-Plastic Coating")
-   hamelsen:outfitAdd("Improved Stabilizer",2)
-   hamelsen:outfitAdd("Gauss Gun",3)
-   hamelsen:setHealth(100,100)
-   hamelsen:setEnergy(100)
+   equipopt.dvaered( majorTam, {
+      cores = {
+         hull = "S&K Skirmish Plating",
+         systems = "Milspec Orion 2301 Core System",
+         engines = "Tricon Zephyr Engine",
+      },
+      prefer = {
+         ["Gauss Gun"] = 100,
+         ["Hellburner"] = 100,
+         ["Improved Stabilizer"] = 100,
+      },
+      outfits_add = {
+         "Hellburner",
+      },
+      move = 0,
+      max_same_weap = 3,
+      max_same_stru = 2,
+      rnd = 0, -- Consistent
+   } )
    hamelsen:setFuel(true)
    hamelsen:setNoDeath() -- We can't afford to loose our main baddie
    hamelsen:setNoDisable()
-   ai_setup.setup(hamelsen)
 
    mem.attack = hook.pilot( hamelsen, "attacked", "hamelsen_attacked" )
 
