@@ -20,7 +20,7 @@
 
    Stages :
    0) Goto find Hamfresser
-   1) First try. TODO: tell the player it's preferable to have refueled just before jumping in Ginger
+   1) First try. TODO: tell the player it's preferable to have refuelled just before jumping in Ginger
    2) Fleeing first time. TODO: see if it's possible to jettison the bomb (and make it not possible)
    3) Second try
    4) Fight with the Phalanx
@@ -113,7 +113,7 @@ end
 function hamfresser()
    if (player.fleetCargoMissionFree() >= bombMass) then
       tk.msg( _("New passengers"), fmt.f(_([["H... hi", you say, waving timidly. "Are you Captain Hamfresser?". The soldier answers "Of course, as it is written on my name tag." Next to his Captain's insignia, and the logo of the Dvaered Space Infantry (a mace with wings), he points to a small label on his chest that reads "Hamfresser". Hamfresser looks at you from top to bottom "You're the private pilot, right? Tell me your ship's dock number, and I'll meet you there. Oh, and please make room for {tonnes} of cargo."
-   The captain then gets up, delicately puts his empty glass on the counter, and leaves. While his hair brushes the ceiling, you wonder if {tonnes} are enough to accommodate him. When you arrive at the dock, you see Hamfresser, with five other soldiers and two androids that load a huge and strange machine into your ship. "Hey," you say, "what are you doing with your... your death machine?" Hamfresser approaches and answers at low voice "But, mate, this is not a death machine, It's just a bomb. Or even just a bomblet."]]), {tonnes=fmt.tonnes(bombMass)}) )
+   The captain then gets up, delicately puts his empty glass on the counter, and leaves. While his hairbrushes the ceiling, you wonder if {tonnes} are enough to accommodate him. When you arrive at the dock, you see Hamfresser, with five other soldiers and two androids that load a huge and strange machine into your ship. "Hey," you say, "what are you doing with your... your death machine?" Hamfresser approaches and answers at low voice "But, mate, this is not a death machine, It's just a bomb. Or even just a bomblet."]]), {tonnes=fmt.tonnes(bombMass)}) )
       tk.msg( _("New passengers"), _([["Very well," you acquiesce, "do what you have to do." Once the cargo is loaded and the team has taken their places in the cabin, you start to talk with the captain. "And I suppose this bomblet is destined for Battleaddict's Goddard. How are we supposed to put it there? Are we going to pretend it's a gift from the High Command to his granddaughter?". Hamfresser looks at you surprised. "No... that's not what the Major... do you think it could work?" You realize it would take too long to explain that it was a sarcastic comment (assuming that this guy knew what sarcasm is) and simply ask him to explain the major's plan.
    "Last period, we intercepted a message from Battleaddict to a plumber. His cruiser has issues with sewage disposal, and he requested an intervention. So, we abducted the plumber, and we disguised an EMP bomb as a replacement sewage disposal. We will dock with his ship, plant the bomb, repair the breakdown (so he won't suspect us) and leave. Private Ling here is a Goddard-plumber, so she will lead us." A young and smiling soldier raises her hand, and says "Hi".]]) )
       tk.msg( _("New passengers"), fmt.f(_([[While you wonder whether the plan is insanely brilliant or dead stupid, Hamfresser begins the introductions. "This is Sergeant Nikolov, she is my second in command, this is Private Tronk, from my squad, and Corporal Therus, our medical support. Oh, and the guy in the corner over there is Lieutenant Strafer. He is a pilot from Special Operations. He is here in case we need to switch to plan B." As you ask what plan B is, Hamfresser simply answers, "you don't want to switch to plan B.
@@ -234,9 +234,9 @@ end
 -- Equips a Goddard for a duel, with or without repeating railguns
 function equipGoddard( plt, repeating )
    -- TODO switch to equipopt
-   plt:outfitAdd("S&K Superheavy Combat Plating")
-   plt:outfitAdd("Melendez Mammoth XL Engine")
-   plt:outfitAdd("Milspec Orion 9901 Core System")
+   plt:outfitAdd("S&K War Plating",2)
+   plt:outfitAdd("Melendez Mammoth Engine",2)
+   plt:outfitAdd("Milspec Orion 8601 Core System",2)
    plt:outfitAdd("Nanobond Plating", 6)
    plt:outfitAdd("Milspec Impacto-Plastic Coating")
    plt:outfitAdd("Droid Repair Crew",4)
@@ -275,7 +275,7 @@ end
 
 -- Battleaddict sees that the player is not a plumber
 function killing()
-   tk.msg(_("That could have worked"), fmt.f(_([[While on approach, you get a better look at the surface of the cruiser. You see a dozen shuttles transporting material and tools from the planet to the ship. As you get closer, you remark that the cruiser looks like an huge construction site with workers in spacesuits welding nanobond reinforcement plates on the hull. Behind you you hear the chatter of the escort ships, which Hamfresser and his team are anxiously listening to: "Hey, Zog, I'm getting concerned about my daughter. Her teacher told me she was non-violent with her classmates. Do you think I should see a specialist?" "Meh, I don't know, honestly. The new holomovies are to blame. There is always less violence and more love in there. The government should take measures."
+   tk.msg(_("That could have worked"), fmt.f(_([[While on approach, you get a better look at the surface of the cruiser. You see a dozen shuttles transporting material and tools from the planet to the ship. As you get closer, you remark that the cruiser looks like a huge construction site with workers in spacesuits welding nanobond reinforcement plates on the hull. Behind you, you hear the chatter of the escort ships, which Hamfresser and his team are anxiously listening to: "Hey, Zog, I'm getting concerned about my daughter. Her teacher told me she was non-violent with her classmates. Do you think I should see a specialist?" "Meh, I don't know, honestly. The new holomovies are to blame. There is always less violence and more love in there. The government should take measures."
    Suddenly, a message makes everyone come to a halt: "So, Colonel, when do we take those fake plumbers out? I look forward to using my shredders a bit!" "Shut up, Corporal!" "Oah, come on, I'm on the encoded channel. The plumbers aren't able to break our code." "But they're NOT plumbers, stupid!"
    Hamfresser looks at you and declares "We're aborting the mission. Get us out of this system, {player}!" Strangely enough, none of the soldiers seem to show any sign of panic.]]), {player=player.name()}))
    release_baddies()
@@ -314,7 +314,7 @@ function spawn_phalanx()
    p:hyperspace( mem.nextsys, true ) -- Go towards Battleaddict's place
 
    -- TODO switch to equipopt
-   p:outfitAdd("S&K Medium Combat Plating")
+   p:outfitAdd("S&K Battle Plating")
    p:outfitAdd("Milspec Orion 4801 Core System")
    p:outfitAdd("Tricon Cyclone Engine")
    p:outfitAdd("Turreted Vulcan Gun", 2)
@@ -356,7 +356,7 @@ function phalanx_boarded()
    hook.rm(mem.pjump)
    hook.rm(mem.pland)
    tk.msg( _("Boarding"), fmt.f(_([[All the members of the commando unit have put on their battle suits. Hamfresser gives the final orders. "Nikolov, Tronk, and I will enter first and clear the area. Remember, we don't have our usual Dudley combat androids. We're stuck with the two useless plumber bots and the few security droids of {player}'s ship so we'll have to get our hands dirty. Corvettes are typically protected by a few 629 Spitfires and an occasional 711 Grillmeister. That's not very much, but still enough to send the inattentive soldier ad patres."
-   When the corvette's airlock falls under Nikolov's circular saw, the captain waves and the small team enters the ship. You hear shots and explosions coming from further and further into the enemy ship. Finally, you hear a laconic message coming from the disabled corvette: "Strafer here, everything went well. We'll now transfer the cargo into the Phalanx... Now that the maneuver is finished, you may leave." Happy to have survived the operation so far, you start your engines and respond "Good luck, folks!" The lieutenant answers "Thanks, citizen, I'm glad to have met you."]]), {player=player.name()}) )
+   When the corvette's airlock falls under Nikolov's circular saw, the captain waves and the small team enters the ship. You hear shots and explosions coming from further and further into the enemy ship. Finally, you hear a laconic message coming from the disabled corvette: "Strafer here, everything went well. We'll now transfer the cargo into the Phalanx... Now that the manoeuvre is finished, you may leave." Happy to have survived the operation so far, you start your engines and respond "Good luck, folks!" The lieutenant answers "Thanks, citizen, I'm glad to have met you."]]), {player=player.name()}) )
    mem.stage = 5
    misn.cargoRm(mem.bomblet)
 
@@ -512,7 +512,7 @@ end
 -- Epilogue
 function endMisn()
    tk.msg( _("A good thing done"), fmt.f(_([[As you approach, the major tells General Klank that you are the private pilot they hired recently. "I see," says the general "so you are one of the people I have to thank for still being alive now." You answer that he apparently would not have needed help if Battleaddict had not cheated as well, and he responds: "Damn fake electricians; I should have suspected something. Anyway, citizen, rest assured that we will need your services again." A group of generals approach and congratulate Klank. He stands up and leaves with them, loudly exchanging dubious pleasantries.
-   Major Tam speaks to you: "Apparently, Battleaddict had a commando unit dress like electricians and hide an EMP bomb in the General's Goddard. It exploded during the fight, just like our own bomb. And now both ships have their systems ruined. Well, anyway, thank you for your help, here are {credits} for you!"]]), {credits=fmt.credits(fw.credits_01)}) )
+   Major Tam speaks to you: "Apparently, Battleaddict had a commando unit dress like electricians and hide an EMP bomb in the General's Goddard. It exploded during the fight, just like our own bomb. And now both ships have their systems ruined. Well, anyway, thank you for your help, here are {credits} for you!"]]), {credits="#g"..fmt.credits(fw.credits_01).."#0"}) )
    player.pay(fw.credits_01)
    shiplog.create( "dvaered_military", _("Dvaered Military Coordination"), _("Dvaered") )
    shiplog.append( "dvaered_military", _("Major Tam's superior, General Klank, had a Goddard duel with Lord Battleaddict. You took part in an operation to sabotage Battleaddict's cruiser. Lord Battleaddict sabotaged Klank's cruiser as well, but at the end of the day, General Klank won the duel.") )
