@@ -49,16 +49,18 @@ local radius = 4000
 local mace_fail = _("Your only weapons should be Mace rockets: land and speak again with Major Tam.")
 
 -- Joy cries (for the Mace throw)
-local joy = { _("Wohoo!"),
-        _("One less!"),
-        _("Baoum!"),
-        _("I'm in such good shape!"),
-        _("Top score, here I come!"),
-        _("Eat that, you Llama freak!"),
-        _("I am so a-Mace-ing!"), -- Yep, I remember the puns I read on discord
-        _("Dodge that!"),
-        _("I got one right in the a... Hem. The engine..."),
-        _("Got you!"),}
+local joy = {
+   _("Wohoo!"),
+   _("One less!"),
+   _("Baoum!"),
+   _("I'm in such good shape!"),
+   _("Top score, here I come!"),
+   _("Eat that, you Llama freak!"),
+   _("I am so a-Mace-ing!"), -- Yep, I remember the puns I read on discord
+   _("Dodge that!"),
+   _("I got one right in the a... Hem. The engine..."),
+   _("Got you!"),
+}
 
 function create()
    if not misn.claim(destsys) then
@@ -94,22 +96,24 @@ function create()
 
    -- Prepare storing of total scores of competitors
    mem.score_total = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 }
-   mem.competitors_names = { _("Major Tam"),
-                         _("Captain Leblanc"),
-                         _("General Klank"),
-                         _("Sergeant Strafer"),
-                         _("Private Micoult"),
-                         _("Sergeant Garcia"),
-                         _("Corporal Johnson"),
-                         _("Private Ernst"),
-                         _("Lieutenant Guo"),
-                         player.name(), }
+   mem.competitors_names = {
+      _("Major Tam"),
+      _("Captain Leblanc"),
+      _("General Klank"),
+      _("Sergeant Strafer"),
+      _("Private Micoult"),
+      _("Sergeant Garcia"),
+      _("Corporal Johnson"),
+      _("Private Ernst"),
+      _("Lieutenant Guo"),
+      player.name(),
+   }
 end
 
 local cargo_flowers
 local function _flowers()
    if not cargo_flowers then
-      cargo_flowers = commodity.new( N_("Flowers"), N_("Pretty flowers."), {gfx_space="flowers.webp"} )
+      cargo_flowers = commodity.new( N_("Flowers"), N_("Pretty flowers."), {gfx_space="flowers"} )
    end
    return cargo_flowers
 end
@@ -217,16 +221,16 @@ function spawnNpcs()
                tk.msg("",fmt.f(_("You receive a {1} as a reward."), {_("Vendetta")}))
                player.shipAdd("Vendetta", nil, _("You obtained this ship as a reward from Mace Rocket Ballet."))
             elseif playerRank == 8 then
-               tk.msg("",fmt.f(_("You receive a {1} and a {2} as a reward."), {_("Tricon Zephyr II Engine"),_("Emergency Shield Booster")}))
-               player.outfitAdd("Tricon Zephyr II Engine")
+               tk.msg("",fmt.f(_("You receive a {1} x2 and a {2} as a reward."), {_("Tricon Zephyr Engine"),_("Emergency Shield Booster")}))
+               player.outfitAdd("Tricon Zephyr Engine",2)
                player.outfitAdd("Emergency Shield Booster")
             elseif playerRank == 7 then
-               tk.msg("",fmt.f(_("You receive a {1} and a {2} as a reward."), {_("Milspec Orion 3701 Core System"),_("Shield Capacitor I")}))
-               player.outfitAdd("Milspec Orion 3701 Core System")
+               tk.msg("",fmt.f(_("You receive two {1}s and a {2} as a reward."), {_("Milspec Orion 2301 Core System"),_("Shield Capacitor I")}))
+               player.outfitAdd("Milspec Orion 2301 Core System",2)
                player.outfitAdd("Shield Capacitor I")
             elseif playerRank == 6 then
-               tk.msg("",fmt.f(_("You receive a {1} as a reward."), {_("S&K Light Combat Plating")}))
-               player.outfitAdd("S&K Light Combat Plating")
+               tk.msg("",fmt.f(_("You receive a {1} as a reward."), {_("S&K Skirmish Plating x2")}))
+               player.outfitAdd("S&K Skirmish Plating",2)
             elseif playerRank == 5 then
                tk.msg("",_("You receive three Shredders as a reward."))
                player.outfitAdd("Shredder",3)
@@ -352,7 +356,7 @@ end
 -- Take off for the next stage
 function takeoff()
    local pos
-   mem.center = destpla:pos() + vec2.new(0,radius)
+   mem.centre = destpla:pos() + vec2.new(0,radius)
 
    if mem.stage == 2 then -- Mace Throw: spawn Llamas and competitors.
       -- Check the player only has mace rockets
@@ -369,16 +373,16 @@ function takeoff()
          pilot.clear()
          spawnCompetitors()
          player.pilot():control()
-         player.pilot():face(mem.center)
+         player.pilot():face(mem.centre)
 
          local fwarlords = fw.fct_warlords()
          targets = {}
          for i = 1, 30 do
-            pos = mem.center + vec2.newP( rnd.rnd(0,radius), rnd.angle() )
+            pos = mem.centre + vec2.newP( rnd.rnd(0,radius), rnd.angle() )
             targets[i] = pilot.add( "Llama", fwarlords, pos, _("Target "))
             targets[i]:control()
             targets[i]:setHostile() -- Just in case
-            pos = mem.center + vec2.newP( rnd.rnd(0,radius), rnd.angle() )
+            pos = mem.centre + vec2.newP( rnd.rnd(0,radius), rnd.angle() )
             targets[i]:moveto( pos, false, false )
             hook.pilot( targets[i], "idle", "targetIdle" )
             hook.pilot( targets[i], "attacked", "targetHit" )
@@ -418,7 +422,7 @@ function takeoff()
       pilot.clear()
       spawnCompetitors( )
       player.pilot():control()
-      player.pilot():face(mem.center)
+      player.pilot():face(mem.centre)
 
       for i, p in ipairs(competitors) do
          p:setNoDeath() -- Bouuuh! they r cheating!
@@ -428,7 +432,7 @@ function takeoff()
       local fwarlords = fw.fct_warlords()
       annoyers = {}
       for i = 1, 10 do
-         pos = mem.center + vec2.newP( rnd.rnd(0,radius-500), rnd.angle() )
+         pos = mem.centre + vec2.newP( rnd.rnd(0,radius-500), rnd.angle() )
          annoyers[i] = pilot.add( "Dvaered Vendetta", fwarlords, pos, _("Shooter"))
          fw.equipVendettaMace( annoyers[i] )
          annoyers[i]:setSpeedLimit( .0001 )
@@ -437,7 +441,7 @@ function takeoff()
 
       local cflowers = _flowers()
       for i = 1, 60 do
-         pos = mem.center + vec2.newP( rnd.rnd(0,radius), rnd.angle() )
+         pos = mem.centre + vec2.newP( rnd.rnd(0,radius), rnd.angle() )
          system.addGatherable( cflowers, 1, pos, vec2.new(0,0), 3600 )
       end
 
@@ -467,7 +471,7 @@ function takeoff()
          pilot.clear()
          spawnCompetitors( )
          player.pilot():control()
-         player.pilot():face(mem.center)
+         player.pilot():face(mem.centre)
 
          compHitHook = {nil,nil,nil,nil,nil,nil,nil,nil,nil}
          mem.playerHitHook = hook.pilot( player.pilot(), "attacked", "playerHit" )
@@ -613,20 +617,20 @@ function spawnCompetitors( )
    local fdhc = fw.fct_dhc()
    competitors = {} -- tam, leblanc, klank, strafer, caros, micoult, johnson, ernst, guo
    for i = 1, 9 do
-      local pos = mem.center + vec2.newP( radius, i*math.pi/5 - math.pi/2 )
+      local pos = mem.centre + vec2.newP( radius, i*math.pi/5 - math.pi/2 )
       competitors[i] = pilot.add( "Dvaered Vendetta", fdhc, pos, mem.competitors_names[i])
       fw.equipVendettaMace( competitors[i] )
       competitors[i]:memory().Cindex = i -- Store their index
       competitors[i]:setVisible()
       competitors[i]:control()
-      competitors[i]:face(mem.center)
+      competitors[i]:face(mem.centre)
       hook.pilot( competitors[i], "death", "compDie" )
    end
 end
 
 -- One of the targets is idle (Mace Throw)
 function targetIdle( self )
-   local pos = mem.center + vec2.newP( rnd.rnd(0,radius), rnd.angle() )
+   local pos = mem.centre + vec2.newP( rnd.rnd(0,radius), rnd.angle() )
    self:moveto( pos, false, false )
 end
 
