@@ -1,15 +1,11 @@
 --[[
 <?xml version='1.0' encoding='utf8'?>
 <mission name="Kex's Freedom 5">
- <flags>
-  <unique />
- </flags>
- <avail>
-  <location>Bar</location>
-  <chance>100</chance>
-  <planet>Minerva Station</planet>
-  <done>Kex's Freedom 4</done>
- </avail>
+ <unique />
+ <location>Bar</location>
+ <chance>100</chance>
+ <spob>Minerva Station</spob>
+ <done>Kex's Freedom 4</done>
  <notes>
   <campaign>Minerva</campaign>
  </notes>
@@ -42,12 +38,10 @@ local lmisn = require "lmisn"
 --  3: return to kex
 mem.misn_state = nil
 local strangelove_ship, thug_leader, thug_pilots -- Non-persistent state
--- luacheck: globals enter landed strangelove_board strangelove_dead strangelove_hail thug_check thug_heartbeat thugs_cleared (Hook functions passed by name)
--- luacheck: globals approach_kex (NPC functions passed by name)
 
 local landed_lab -- Forward-declared functions
 
-local targetplanet = planet.get("Strangelove Lab")
+local targetplanet = spob.get("Strangelove Lab")
 local targetsys = system.get("Westhaven") --same as targetplanet:system(), but only after the below diff gets applied
 
 local eccdiff = "strangelove"
@@ -75,7 +69,7 @@ function accept ()
    vn.transition( "hexagon" )
 
    vn.na(_("You approach Kex, who is sort of slumping at his usual spot. He doesn't seem to be in very good condition."))
-   kex(_([[It takes a bit before Kex notices your presence. His feathers are rather disheveled.
+   kex(_([[It takes a bit before Kex notices your presence. His feathers are rather dishevelled.
 "Oh, hey kid."]]))
    kex(_([[It takes a while before he continues.
 "Compared to the vastness of all the universe, we are completely insignificant. Our sorrows and glories go unheard and seemingly devoid of all meaning."]]))
@@ -122,11 +116,11 @@ function accept ()
 end
 
 function landed ()
-   -- Can't use planet.get() here for when the diff is removed
-   if mem.misn_state==1 and planet.cur() == targetplanet then
+   -- Can't use spob.get() here for when the diff is removed
+   if mem.misn_state==1 and spob.cur() == targetplanet then
       landed_lab()
 
-   elseif mem.misn_state==3 and planet.get("Minerva Station")==planet.cur() then
+   elseif mem.misn_state==3 and spob.get("Minerva Station")==spob.cur() then
       misn.npcAdd( "approach_kex", minerva.kex.name, minerva.kex.portrait, minerva.kex.description )
    end
 end
@@ -144,7 +138,7 @@ function approach_kex ()
    vn.transition( "hexagon" )
    vn.na(_("You approach Kex who is sort of slumping at his usual spot. He doesn't seem much better than last time you met him."))
    kex(_([["Hey kid."
-He seems a bit nervious and speaks softer than usual.
+He seems a bit nervous and speaks softer than usual.
 "Did you do what I asked?"]]))
 
    if strangelove_death=="comforted" then
@@ -233,7 +227,7 @@ function enter ()
       local fbh = faction.dynAdd( "Mercenary", "kex_bountyhunter", _("Bounty Hunter"), {ai="baddie_norun"} )
       thug_pilots = {}
       for k,v in ipairs(thugs) do
-         local ppos = pos + vec2.new( rnd.rnd()*200, rnd.rnd()*360 )
+         local ppos = pos + vec2.newP( rnd.rnd()*200, rnd.angle() )
          local p = pilot.add( v, fbh, ppos, nil, {naked=true} )
          equipopt.pirate( p )
          if not thug_leader then
@@ -266,7 +260,7 @@ function enter ()
          local pos = targetplanet:pos()
          spawn_thugs( pos, false )
          hook.timer( 5, "thug_heartbeat" )
-         player.allowLand( false, _("#rYou are unable to land while the bounty hunters are still active.#0") )
+         player.landAllow( false, "#r".._("You are unable to land while the bounty hunters are still active.").."#0" )
 
          hook.timer( 3, "thug_check" )
 
@@ -281,7 +275,7 @@ function enter ()
             local p = pilot.add( d, "Za'lek", pos + vec2.newP( 100+700*rnd.rnd(), rnd.angle() ) )
             p:setInvincible(true)
             p:setInvisible(true)
-            p:disable()
+            p:setDisable()
          end
 
       -- State 1: Do nothing (just in case the player kills bounty hunters and goes off somewhere)
@@ -304,9 +298,9 @@ function enter ()
       end
 
    elseif mem.misn_state~=1 and rnd.rnd() < mem.thug_chance then
-      -- Make sure system isn't claimed, but we don't claim it
-      if misn.claim( system.cur(), true ) then
-         -- Spawn near the center, they home in on player
+      -- Make sure system isn't claimed, but we don't claim it (inclusive test)
+      if naev.claimTest( system.cur(), true ) then
+         -- Spawn near the centre, they home in on player
          spawn_thugs( vec2.newP(0.7*system.cur():radius()*rnd.rnd(), rnd.angle()), false )
          -- Timer
          hook.timer( 5, "thug_heartbeat" )
@@ -388,7 +382,7 @@ function thugs_cleared ()
    vn.run()
 
    mem.misn_state = 1
-   player.allowLand( true )
+   player.landAllow( true )
 end
 
 function landed_lab ()
@@ -423,15 +417,15 @@ function landed_lab ()
    end )
 
    vn.label("living")
-   vn.na(_("You make your way through a tight, nearly impassible passageway towards the living quarters. Although it is a mess, you don't really see any signs of anyone living here. It rather seems all abandoned."))
+   vn.na(_("You make your way through a tight, nearly impassable passageway towards the living quarters. Although it is a mess, you don't really see any signs of anyone living here. It rather seems all abandoned."))
    vn.na(_("Eventually, you reach a very small room with a bed capsule. The ground and bed are splattered with blood, but it seems very old and desiccated. Some empty medical syringes and pouches are scattered on the floor."))
    vn.na(_("You turn over everything, but find nothing of interest."))
    vn.func( function () check_living = true end )
    vn.jump("menu")
 
    vn.label("recreation")
-   vn.na(_("You head towards, and eventually reach, the recreation room, which has been completely trashed. Even pieces of the wall have been ripped out, revealing shoddy cable connections and lots of weird mold."))
-   vn.na(_("Looking around, you find that the hologram projector you used last time is, unsurprisingly, completely wrecked. It doesn't seem like you'll be able to use it to get in touch with Dr. Strangelove anymore."))
+   vn.na(_("You head towards, and eventually reach, the recreation room, which has been completely trashed. Even pieces of the wall have been ripped out, revealing shoddy cable connections and lots of weird mould."))
+   vn.na(_("Looking around, you find that the hologram projector you used last time is, unsurprisingly, completely wrecked. It doesn't seem like you'll be able to use it to get in touch with Dr. Strangelove any more."))
    vn.na(_("Try as you might, you are unable to find anything of interest."))
    vn.func( function () check_rr = true end )
    vn.jump("menu")
@@ -460,7 +454,7 @@ function landed_lab ()
    player.takeoff()
 
    -- Disable landing, will get disabled on entering new system
-   player.allowLand( false, _("You have better things to do right now.") )
+   player.landAllow( false, _("You have better things to do right now.") )
 end
 
 function strangelove_hail ()
@@ -491,6 +485,7 @@ function strangelove_board ()
    vn.clear()
    vn.scene()
    local dr = minerva.vn_strangelove()
+   vn.transition()
    -- TODO small scene
    vn.na(_("You cautiously board the ship, not sure what you are about to encounter. Trusting your system's sensors indicating a proper atmosphere in the ship, you board without your space suit. However, when you enter the ship, a strong, pungent odour makes you regret your decision."))
    vn.na(_("As you move to the command room, you notice small movements from the corner of your eyes. Upon closer inspection you make out all sorts of small moving objects, reminding you of cleaning droids on most ships, however, these move in a fairly clunky fashion, as if they had some of their moving apparatus damaged."))
@@ -498,7 +493,7 @@ function strangelove_board ()
    love_audio.setEffect( "reverb_psychotic", reverb_preset.psychotic() )
    vn.music( minerva.loops.strangelove, {effect="reverb_psychotic"} )
    vn.appear(dr)
-   vn.na(_("You enter the room and meet Dr. Strangelove face-to-face for the first time. Dr. Strangelove is laid out in a medical bed connected to a lot of weird machines, with a medical droid attending him. If it weren't for the fact that everything is fairly rundown and dirty, you would think you were in a planetary hospital instead of a space ship at the edge of the universe."))
+   vn.na(_("You enter the room and meet Dr. Strangelove face-to-face for the first time. Dr. Strangelove is laid out in a medical bed connected to a lot of weird machines, with a medical droid attending him. If it weren't for the fact that everything is fairly rundown and dirty, you would think you were in a planetary hospital instead of a spaceship at the edge of the universe."))
    dr(_("You take a close look at Dr. Strangelove, and he seems like a husk of what might have once been a man. His cheekbones protrude from his pale face and his laboratory coat seems to be a few sizes too large on his frail body. His vitals monitor also confirms your suspicion that he is more dead than alive."))
    dr(_([["I see you were able to make it."
 He coughs violently.
@@ -549,7 +544,7 @@ His voice tears up slightly.]]))
    vn.label("2cont")
    dr(_([["Why did you have to kill yourself?"
 His sightless eyes look vacantly while tears flow down his face.]]))
-   dr(_([[You don't know how to answer and silence envelopes the room. Finally, he breaks the calmness.
+   dr(_([[You don't know how to answer and silence envelops the room. Finally, he breaks the calmness.
 "I should have been the one to try to defuse the reactor core, not you. I should have been the one vaporized in the resulting explosion, not you."]]))
    dr(_([[The vitals monitor starts flashing red, and the medical droid begins to tweak and make adjustments to intravenous drips and other medical devices.
 He coughs a bit and you can see blood flecks splatter onto his clothes.]]))
@@ -621,11 +616,11 @@ His talking is slowing down and starting to get muddled. You have trouble making
    vn.label("4cont")
    vn.na(_([[His lips begin moving and you can hear some sort of rasping sound coming out, however, you can no longer make out what he is saying. You glance at the monitors and you see his vitals are tanking. It looks like he has run out of time.]]))
    vn.label("nonviolent_death")
-   vn.na(_([[He slowly lifts up an arm as if trying to reach out and grasp something. It it extremely thin and pale, almost transparent. His lips move as if trying to say something, but you can't make out a single sound. You see the strength slowly ebb out of him as he collapses one last time and his pulse flatlines.]]))
+   vn.na(_([[He slowly lifts up an arm as if trying to reach out and grasp something. It is extremely thin and pale, almost transparent. His lips move as if trying to say something, but you can't make out a single sound. You see the strength slowly ebb out of him as he collapses one last time and his pulse flat lines.]]))
    vn.disappear( dr, "slideup", nil, "ease-out" ) -- played backwards so should be down
    vn.label("dr_death")
    vn.musicStop() -- Stop music
-   vn.na(_([[Silence once again envelopes the room. You look around and decide to try to access the command console to see if there is any information left. It is a bit unsettling with a corpse nearby, but you try to focus on getting the grime off the console and interfacing with it. ]]))
+   vn.na(_([[Silence once again envelops the room. You look around and decide to try to access the command console to see if there is any information left. It is a bit unsettling with a corpse nearby, but you try to focus on getting the grime off the console and interfacing with it. ]]))
    vn.na(_([[You notice that everything seems to be heavily encrypted, much more so than the standard on even military Za'lek vessels, and try to break into the system. After a few unsuccessful attempts you manage to find what looks like a flaw in the cryptographic armour and try to access it.]]))
    vn.na(_([[Suddenly a bright message starts flashing on all the monitors:
 #rHONEYPOT ##329 ACTIVATED
@@ -701,7 +696,7 @@ He seems to be looking at something in the distance.]]))
    -- Advance mission
    mem.misn_state = 3
    misn.osdActive(2)
-   misn.markerMove( mem.misn_marker, planet.get("Minerva Station") )
+   misn.markerMove( mem.misn_marker, spob.get("Minerva Station") )
    player.unboard()
    local strangelove_death = var.peek("strangelove_death")
    if strangelove_death=="shot" then
