@@ -1,16 +1,12 @@
 --[[
 <?xml version='1.0' encoding='utf8'?>
 <mission name="Maikki's Father 2">
- <flags>
-  <unique />
- </flags>
- <avail>
-  <priority>4</priority>
-  <chance>100</chance>
-  <location>Bar</location>
-  <planet>Minerva Station</planet>
-  <done>Maikki's Father 1</done>
- </avail>
+ <unique />
+ <priority>4</priority>
+ <chance>100</chance>
+ <location>Bar</location>
+ <spob>Minerva Station</spob>
+ <done>Maikki's Father 1</done>
  <notes>
   <campaign>Minerva</campaign>
  </notes>
@@ -24,7 +20,7 @@
 --
 -- 1. Told to try to find who could have been involved and given three places to look at.
 -- Hint 1: Jorla in Regas (University)
--- Hint 2: Cantina Station in Qulam (Trade Hub)
+-- Hint 2: Cantina Centre in Qulam (Trade Hub)
 -- Hint 3: Jurai in Hideyoshi's Star (University)
 -- 2. After talking to all three, the player is told to go to Naga in Damien (Underwater University)
 -- 3. Mentions eccentric colleague at Westhaven
@@ -40,41 +36,41 @@ local love_shaders = require 'love_shaders'
 local fmt = require "format"
 
 local hint1_name = _("Prof. Sato") -- Computer Science / Mathematics
-local hint1_portrait = "zalek1.png"
-local hint1_image = "zalek1.png"
+local hint1_portrait = "zalek1"
+local hint1_image = "zalek1"
 local hint1_colour = nil
 
 local hint2_name = _("Prof. Stova") -- Material Science
-local hint3_portrait = "zalek3.webp"
-local hint3_image = "zalek3.webp"
+local hint3_portrait = "zalek3"
+local hint3_image = "zalek3"
 local hint2_colour = nil
 
 local hint3_name = _("Prof. Hsu") -- Philosophy
-local hint2_portrait = "zalek2.png"
-local hint2_image = "zalek2.png"
+local hint2_portrait = "zalek2"
+local hint2_image = "zalek2"
 local hint3_colour = nil
 
 local hint4_name = _("Dr. Cayne") -- Dr. Shrimp
-local hint4_portrait = "drshrimp.png"
-local hint4_image = "drshrimp.png"
+local hint4_portrait = "drshrimp"
+local hint4_image = "drshrimp"
 local hint4_colour = nil
 
 local ecc_portrait = minerva.strangelove.portrait
 
 local hintpnt = {
    "Jorla",
-   "Cantina Station",
+   "Cantina Centre",
    "Jurai",
    "Naga",
 }
 local hintsys = {}
 for k,v in ipairs(hintpnt) do
-   hintsys[k] = planet.get(v):system()
+   hintsys[k] = spob.get(v):system()
 end
 local eccpnt = "Strangelove Lab"
 local eccdiff = "strangelove"
 local eccsys = system.get( "Westhaven" )
-local eccpos = vec2.new( 7500, -6000 ) -- Should coincide with "Strangelove Lab"
+local eccpos = spob.get(eccpnt):pos() -- Coincides with "Strangelove Lab"
 
 -- Mission states:
 --  nil: mission not yet accepted
@@ -86,10 +82,8 @@ local eccpos = vec2.new( 7500, -6000 ) -- Should coincide with "Strangelove Lab"
 --    5: Got the artefacts
 --    6: Going back to Minerva Station
 mem.misn_state = nil
-local defense_systems, feral_drone_boss -- Non-persistent state
+local defence_systems, feral_drone_boss -- Non-persistent state
 local hintosd -- Forward-declared functions
--- luacheck: globals ecc_dist ecc_drone_dead_check ecc_feral_boss_attacked ecc_feral_boss_dead ecc_feral_boss_msg ecc_timer ecc_timer_dead enter generate_npc (Hook functions passed by name)
--- luacheck: globals approach_eccentric approach_hint1 approach_hint2 approach_hint3 approach_hint4 approach_maikki (NPC functions passed by name)
 
 function create ()
    if not misn.claim( eccsys ) then
@@ -111,9 +105,9 @@ function accept ()
    end
 
    -- Set up mission stuff
-   mem.markerhint1 = misn.markerAdd( planet.get(hintpnt[1]), "low")
-   mem.markerhint2 = misn.markerAdd( planet.get(hintpnt[2]), "low")
-   mem.markerhint3 = misn.markerAdd( planet.get(hintpnt[3]), "low")
+   mem.markerhint1 = misn.markerAdd( spob.get(hintpnt[1]), "low")
+   mem.markerhint2 = misn.markerAdd( spob.get(hintpnt[2]), "low")
+   mem.markerhint3 = misn.markerAdd( spob.get(hintpnt[3]), "low")
    hintosd()
    hook.land("generate_npc")
    hook.load("generate_npc")
@@ -240,7 +234,7 @@ She winks at you.]]))
    vn.menu( opts )
 
    vn.label( "researchers" )
-   maikki(_([["The researchers I told you about were involved in some sort of project trying to find out the origins of the incident by analyzing artefacts taken from the nebula. Most of it is classified so I wasn't able to get much information."]]))
+   maikki(_([["The researchers I told you about were involved in some sort of project trying to find out the origins of the Incident by analysing artefacts taken from the nebula. Most of it is classified so I wasn't able to get much information."]]))
    maikki(_([["Apparently the project was disbanded for some reason or other, and some members went missing. However, I was able to track down a few of them, but it wasn't too easy. They have some weird system called tenure that nobody understands and makes them move constantly from research laboratory to research laboratory. So droll!"]]))
    seekoutmsg()
    maikki(_([["I don't think it will be easy for you to get information from the Za'lek. They never give a straight answer and it's all "that is illogical" and "ma'am that beaker of acid is not a toy". So boring!"
@@ -251,8 +245,8 @@ She frowns and shakes her head.]]))
    vn.label( "father" )
    maikki(_([["I don't remember much about my father, most of what I know about him are from stories from my late mother and pilots who knew him."]]))
    maikki(_([[Her eyes light up.
-"Did you know that while scavenging near the incident, an asteroid hit his thrusters making them point the wrong way and he had to fly backwards through five systems in the nebula while chased by pirates? Sounds crazy!"]]))
-   maikki(_([["They say he was also the first pilot to chart all the systems in the Nebula after the incident. Not even getting his leg crushed while recovering parts of the last emperor's flagship stopped him from going back and back to the nebula."]]))
+"Did you know that while scavenging near the Incident, an asteroid hit his thrusters making them point the wrong way and he had to fly backwards through five systems in the nebula while chased by pirates? Sounds crazy!"]]))
+   maikki(_([["They say he was also the first pilot to chart all the systems in the Nebula after the Incident. Not even getting his leg crushed while recovering parts of the last emperor's flagship stopped him from going back and back to the nebula."]]))
    maikki(_([[Her eyes darken a little and her voice softens.
 "His obsession with finding the truth meant he was away from home most of the time and my mother was probably very lonely. She told me he never came to any of my birthdays…"]]))
    maikki(_([[Her eyes light up again.
@@ -299,22 +293,22 @@ end
 
 
 function generate_npc ()
-   if planet.cur() == planet.get("Minerva Station") then
+   if spob.cur() == spob.get("Minerva Station") then
       misn.npcAdd( "approach_maikki", minerva.maikki.name, minerva.maikki.portrait, minerva.maikki.description )
 
-   elseif planet.cur() == planet.get( hintpnt[1] ) then
+   elseif spob.cur() == spob.get( hintpnt[1] ) then
       misn.npcAdd( "approach_hint1", hint1_name, hint1_portrait, _("You see a person in a fancy lab coat. It seems like they are enjoying their time off.") )
 
-   elseif planet.cur() == planet.get( hintpnt[2] ) then
+   elseif spob.cur() == spob.get( hintpnt[2] ) then
       misn.npcAdd( "approach_hint2", hint2_name, hint2_portrait, _("You see a person in a fancy lab coat. It seems like they are enjoying their time off.") )
 
-   elseif planet.cur() == planet.get( hintpnt[3] ) then
+   elseif spob.cur() == spob.get( hintpnt[3] ) then
       misn.npcAdd( "approach_hint3", hint3_name, hint3_portrait, _("You see a person in a fancy lab coat. It seems like they are enjoying their time off.") )
 
-   elseif mem.misn_state >= 1 and  planet.cur() == planet.get( hintpnt[4] ) then
+   elseif mem.misn_state >= 1 and  spob.cur() == spob.get( hintpnt[4] ) then
       misn.npcAdd( "approach_hint4", hint4_name, hint4_portrait, _("You see a young fellow intently reading a book. There seems to be a shrimp floating in a nearby aquarium bowl.") )
 
-   elseif diff.isApplied(eccdiff) and planet.cur() == planet.get(eccpnt) and mem.misn_state < 6 then
+   elseif diff.isApplied(eccdiff) and spob.cur() == spob.get(eccpnt) and mem.misn_state < 6 then
       mem.npc_ecc = misn.npcAdd( "approach_eccentric", _("Hologram Projector"), ecc_portrait, _("An old decrepit hologram projector sits in the corner. It looks like you could use this to communicate with the owner of the station.") )
    end
 end
@@ -338,7 +332,7 @@ end
 local function visited ()
    if mem.misn_state==0 and visitedhints()==3 then
       mem.misn_state = 1
-      mem.markerhint4 = misn.markerAdd( planet.get(hintpnt[4]), "low" )
+      mem.markerhint4 = misn.markerAdd( spob.get(hintpnt[4]), "low" )
       minerva.log.maikki(_("You met the three researchers that Maikki told you about and found out a lead about another researcher.") )
    end
    hintosd()
@@ -363,7 +357,7 @@ function approach_hint1 ()
 
    vn.clear()
    vn.scene()
-   local prof = vn.newCharacter( hint1_name, { image=hint1_image, color=hint1_colour } )
+   local prof = vn.newCharacter( hint1_name, { image=hint1_image, colour=hint1_colour } )
    vn.transition()
 
    vn.na(_("You approach the professor."))
@@ -393,17 +387,17 @@ function approach_hint2 ()
 
    vn.clear()
    vn.scene()
-   local prof = vn.newCharacter( hint2_name, { image=hint2_image, color=hint2_colour } )
+   local prof = vn.newCharacter( hint2_name, { image=hint2_image, colour=hint2_colour } )
    vn.transition()
 
    vn.na(_("You approach the professor."))
    prof(_([["What can I do for you?"]]))
    vn.na(_("You inquire to about whether or not they are interested in artefacts from the nebula."))
-   prof(_([[They rubs their temples.
-"Ah, the nebula artefacts… Not very good experiences with those, no, not really interested in them anymore."]]))
-   prof(_([["I was part of a really ambitious project to try to track down the origin of the incident, which just end up being a bureaucratic nightmare."]]))
+   prof(_([[They rub their temples.
+"Ah, the nebula artefacts… Not very good experiences with those, no, not really interested in them any more."]]))
+   prof(_([["I was part of a really ambitious project to try to track down the origin of the Incident, which just end up being a bureaucratic nightmare."]]))
    prof(_([["You see, the bigger the research project, the more the project leader and co-leaders want to have meetings and goals and work packages."
-They shudder when they says the word "work packages".]]))
+They shudder when they say the word "work packages".]]))
    prof(_([["At the end, we were just chaining meetings and answering e-mails and not getting anything done. We ended up handing in a 5-page report written by an intern for the mid-project evaluation and almost lost all the funding. The project leader panicked and it all went to hell from there."]]))
    prof(_([["All nebula research is doomed to end that way. I haven't seen a project succeed yet, despite all the proposal calls attempting to address the issue."]]))
    vn.na(_("You inquire about other project members."))
@@ -426,7 +420,7 @@ function approach_hint3 ()
 
    vn.clear()
    vn.scene()
-   local prof = vn.newCharacter( hint3_name, { image=hint3_image, color=hint3_colour } )
+   local prof = vn.newCharacter( hint3_name, { image=hint3_image, colour=hint3_colour } )
    vn.transition()
 
    vn.na(_("You approach the professor."))
@@ -440,7 +434,7 @@ function approach_hint3 ()
    prof(_([["Other members? I recall a few, but they liked me so much, they promoted me and gave me a windowless room in the basement. What an honour! Anyway, back to what I was saying."]]))
    prof(_([["We must also further question not only our sensory organs, and the existence of nebula artefacts, but our own existence. We apparently are able to think and some would argue that by this, the only thing we can prove, given imperfect sensory data, is our own existence. However, I argue that this too is an illusion, and that our existence itself is something we can't prove."]]))
    prof(_([["Every instant, what we perceive as ourselves is ceasing to exist and a new existence, which, while very close to the "ourselves" from the previous instance, is, arguably, a completely new existence. This fluidity makes it not only impossible to perceive nor understand our self as it is, but also makes it impossible to draw a line between different individuals…"]]))
-   vn.na(_("You thank them and run away while they keeps on talking to themselves."))
+   vn.na(_("You thank them and run away while they keep on talking to themselves."))
    lasthint( prof )
 
    vn.run()
@@ -457,8 +451,8 @@ function approach_hint4 ()
 
    vn.clear()
    vn.scene()
-   local drshrimp = vn.newCharacter( name, { image=hint4_image, color=hint4_colour } )
-   local shrimp = vn.newCharacter( _("Floating Shrimp"), { color={0.4, 0.6, 1.0} } )
+   local drshrimp = vn.newCharacter( name, { image=hint4_image, colour=hint4_colour } )
+   local shrimp = vn.newCharacter( _("Floating Shrimp"), { colour={0.4, 0.6, 1.0} } )
    vn.transition()
 
    vn.na(_("You approach the young man who has POST-DOCTORAL RESEARCHER written on his lab coat. He seems to be really into a book titled 'SHRIMP: Anatomical studies of the Neo-neo-neocaridina species'."))
@@ -476,7 +470,7 @@ function approach_hint4 ()
       shrimp:rename(_("Calliope"))
       shrimp(_([[A pellet of shrimp food is released into the floating aquarium. The shrimp wastes no time in scarfing it down.
    "HAPPY. GOOD."]]))
-      drshrimp(_([["What do you want?"]]))
+      drshrimp(p_("Dr. Shrimp", [["What do you want?"]]))
       vn.na(_("You explain to him that you are looking for information related to nebula artefacts."))
       drshrimp(_([["Ah, that hellish project. Was doomed from the start, you know. The full-time professors and researchers let their egos get to their heads and it derailed spectacularly. I'm glad it ended as it did, or I would be still stuck in that purgatory."]]))
       drshrimp(_([["I don't think most of the people remember me, but I was the one stuck doing most of the work. If you can call it that."]]))
@@ -532,7 +526,7 @@ He activates her feeding system and a food pellet drops out.]]))
    drshrimp(_([["What sort of artefacts we were dealing with? All sorts. Pretty much anything we could get our hands on. We were trying to get a hold of stuff closer to the origin, near Sol, but, most of the time, scavengers brought us stuff from the outer areas. Many times they were even trying to sell us random debris as nebula artefacts, but that's really easy to detect."]]))
    drshrimp(_([["You see, the nebula emits a specific type of radiation. We aren't too familiar with it, but it does alter the subatomic particles of space debris in nearly imperceptible ways. Our tools could detect the alterations easily."]]))
    drshrimp(_([["When the project failed, most of the artefacts were confiscated to who knows where, but I managed to keep a nut from what I think is a space station, although not entirely sure. It's a bit damaged beyond recognition you see."]]))
-   drshrimp(_([["With the failure of most nebula projects, I don't think there is anybody buying nebula artefacts anymore. Not much of a market for them, and most easy to access debris has all been scavenged anyway. Some collectors are still interested in that, but that's about it. Furthermore, it's not entirely legal if you catch my drift."]]))
+   drshrimp(_([["With the failure of most nebula projects, I don't think there is anybody buying nebula artefacts any more. Not much of a market for them, and most easy to access debris has all been scavenged anyway. Some collectors are still interested in that, but that's about it. Furthermore, it's not entirely legal if you catch my drift."]]))
    vn.func( function () mem.asked_artifacts = true end )
    vn.jump("menu_msg")
 
@@ -549,7 +543,7 @@ He activates her feeding system and a food pellet drops out.]]))
    drshrimp(_([["He was really upset when the project got cancelled, threw a big tantrum and all. He was locked in his office for days until they managed to coax him out. Nobody really did much as we were all busy dealing with all the paperwork of the project cancellation."]]))
    vn.sfxEerie()
    drshrimp(fmt.f(_([["Eventually he sort of disappeared. Last I heard, he said he was going to {sys}, which is a bit strange, because not only is there not a research centre there, but there isn't even an inhabited planet nor station!"]]), {sys=eccsys}))
-   drshrimp(_([["It's really weird but if you are really interested, I suppose you could try to take a look around there. The whole thing gives me the me the creeps though."]]))
+   drshrimp(_([["It's really weird but if you are really interested, I suppose you could try to take a look around there. The whole thing gives me the creeps though."]]))
    vn.func( function ()
       mem.asked_strangelove = true
       if mem.misn_state==1 then
@@ -598,7 +592,7 @@ function enter ()
       b:setHilight(true)
       hook.pilot( b, "attacked", "ecc_feral_boss_attacked" )
       hook.pilot( b, "death", "ecc_feral_boss_dead" )
-      b:setNoboard(true)
+      b:setNoBoard(true)
       local num = 4
       for i=1,num do
          local fpos = pos + vec2.newP( 50, 2*math.pi*i/num )
@@ -614,7 +608,7 @@ end
 function ecc_timer ()
    player.msg(_("Your ship has detected a curious signal originating from inside the system."), true)
    player.autonavReset()
-   mem.sysmarker = system.mrkAdd( eccpos, _("Curious Signal") )
+   mem.sysmarker = system.markerAdd( eccpos, _("Curious Signal") )
    hook.timer( 0.5, "ecc_dist" )
 end
 
@@ -624,22 +618,22 @@ function ecc_dist ()
    local dist = pp:pos():dist( eccpos )
 
    if dist < math.min( pp:detectedDistance(), 3000 ) then
-      system.mrkRm( mem.sysmarker )
+      system.markerRm( mem.sysmarker )
       local spawners = {
          "Za'lek Heavy Drone",
          "Za'lek Light Drone",
          "Za'lek Light Drone",
          "Za'lek Light Drone",
       }
-      defense_systems = {}
+      defence_systems = {}
       for k,v in ipairs(spawners) do
          local pos = eccpos + vec2.newP( rnd.rnd(0,100), rnd.angle() )
          local p = pilot.add( v, "Strangelove", pos, _("Security Drone"), {ai="baddiepos"} )
          p:setHostile()
-         table.insert( defense_systems, p )
+         table.insert( defence_systems, p )
       end
       player.autonavAbort(_("Hostiles detected!"))
-      defense_systems[1]:broadcast(_("UNAUTHORIZED VESSEL DETECTED. ELIMINATING."))
+      defence_systems[1]:broadcast(_("UNAUTHORIZED VESSEL DETECTED. ELIMINATING."))
       hook.timer( 1.0, "ecc_drone_dead_check" )
       return
    end
@@ -648,16 +642,16 @@ end
 
 
 function ecc_drone_dead_check ()
-   local new_defense = {}
-   for k,p in ipairs(defense_systems) do
+   local new_defence = {}
+   for k,p in ipairs(defence_systems) do
       if p:exists() then
-         table.insert( new_defense, p )
+         table.insert( new_defence, p )
       end
    end
-   defense_systems = new_defense
+   defence_systems = new_defence
 
    -- All dead
-   if #defense_systems==0 then
+   if #defence_systems==0 then
       hook.timer( 5.0, "ecc_timer_dead" )
    else
       hook.timer( 1.0, "ecc_drone_dead_check" )
@@ -678,10 +672,10 @@ function ecc_feral_boss_dead ()
    local paperbg = love_shaders.paper()
    vn.clear()
    vn.scene()
-   vn.music( 'snd/sounds/loops/creepy_guitar.ogg' )
+   vn.music( 'snd/sounds/loops/creepy_guitar' )
    vn.func( function ()
       vn.setBackground( function ()
-         vn.setColor( {0.2, 0.2, 0.2, 0.8} )
+         vn.setColour( {0.2, 0.2, 0.2, 0.8} )
          paperbg:draw( 0, 0 )
       end )
       vn.setShader( love_shaders.corruption{ strength=0.5 } )
@@ -706,7 +700,7 @@ end
 local drone_msgs = {
    _("Just destroy me and put me out of my misery."),
    _("Why am I still alive?"),
-   _("I can't deal with this anymore."),
+   _("I can't deal with this any more."),
    _("Please end me!"),
    _("Living is suffering."),
    _("It all hurts."),
@@ -721,9 +715,7 @@ function ecc_feral_boss_attacked( _p )
       hook.timer( 2.0, "ecc_feral_boss_msg" )
 
       -- We go with nebula music
-      music.load("nebu_battle1")
-      music.play()
-      music.setRepeat(true)
+      music.play("nebu_battle1")
    end
 end
 
@@ -757,7 +749,7 @@ You glance at a crate labelled 'NEBULA ARTEFACTS #082' in the corner of the room
       vn.na(_("The hologram projector flickers and Dr. Strangelove comes into view. He doesn't look very happy to see you again."))
    end
    vn.label("menu_msg")
-   dr(_([["What do you want?"]]))
+   dr(p_("Dr. Strangelove", [["What do you want?"]]))
    vn.label("menu")
    vn.menu( function ()
       local opts = {
@@ -774,7 +766,7 @@ You glance at a crate labelled 'NEBULA ARTEFACTS #082' in the corner of the room
    end )
 
    vn.label("nebula")
-   dr(_([["Ah yes, the nebula. The pinnacle of human creation! Isn't it just mesmerizing and beautiful to look at? I've always been attracted to it ever since the incident destroyed my university. Destruction is so pretty, is it not?"]]))
+   dr(_([["Ah yes, the nebula. The pinnacle of human creation! Isn't it just mesmerizing and beautiful to look at? I've always been attracted to it ever since the Incident destroyed my university. Destruction is so pretty, is it not?"]]))
    dr(_([["I recently had the great opportunity to work directly on nebula research. It was a fabulous project with hundreds of the brightest Za'lek minds working in tandem! Not as brilliant as me, but the numbers were what mattered."
 He grins as nostalgia takes him over.]]))
    dr(_([["We were able to have dedicated teams recovering all sorts of incredible items! We even found the remains of a Proteron replicator! It was only able to replicate cheese fondue, but it was incredible. I integrated it with a drone platform and that has kept me healthy and in shape since! It should be in the bar if you want to try it."
@@ -840,7 +832,7 @@ no vitals… not very good… mmmm… nebula radiation at minimum… can't be he
    vn.label("hatethisguy")
    dr(_([["I see… You don't grasp the importance of this artefact. I guess it can't be helped with such an inferior intellect as yours."
 He sneers.]]))
-   dr(_([["This is my latest creation, an amalgamate of ancient nebula technology and life. Think of this as something that not only surpasses any of the Soromid biotechnology, but also Za'lek cybertechnology. It is the peak of technological advancement!"]]))
+   dr(_([["This is my latest creation, amalgamate of ancient nebula technology and life. Think of this as something that not only surpasses any of the Soromid biotechnology, but also Za'lek cybertechnology. It is the peak of technological advancement!"]]))
    dr(_([["While it has an incredible potential, there are… some complications still. The mental faculties tend to lack stability. While this one is a very interesting failure, it is still a failure at heart. Most of my other creations have had much more success."]]))
    dr(_([["What was it you wanted?"]]))
    vn.na(_("You ask him if he knows anything about Kex's ship in the nebula."))
@@ -868,7 +860,7 @@ His voice gets softer and softer as he keeps on mumbling.]]))
       mem.misn_state = 6
       misn.npcRm( mem.npc_ecc )
       misn.osdCreate( _("Finding Maikki's Father"), {_("Report back to Maikki in the Limbo system")} )
-      misn.markerAdd( planet.get("Minerva Station"), "low")
+      misn.markerAdd( spob.get("Minerva Station"), "low")
       misn.markerRm( mem.marker_ecc )
       minerva.log.maikki(_("You learned that Dr. Strangelove saved what appears to be Kex and another individual from a wreck in the nebula. Kex appears to have run away and is likely held by thugs at Minerva station." ) )
    end )
