@@ -20,10 +20,10 @@
 
    This mission has two ways of being done:
    1. Using brute force and killing everything.
-   2. Using stealth if the player boards the drone controllers or hacking center, they can disable drones.
+   2. Using stealth if the player boards the drone controllers or hacking centre, they can disable drones.
 
-   There are drones patrolling the hacking center, it requires disabling two drone controllers to get there.
-   There are also drones wandering around that are independent / depend on the hacking center.
+   There are drones patrolling the hacking centre, it requires disabling two drone controllers to get there.
+   There are also drones wandering around that are independent / depend on the hacking centre.
 --]]
 local minerva = require "common.minerva"
 local vn = require 'vn'
@@ -39,9 +39,9 @@ local mainsys = system.get("Gammacron")
 --  nil: mission not accepted yet
 --    1. fly to mainsys
 --    2. mission time!
---    3. hacking center disabled
+--    3. hacking centre disabled
 mem.misn_state = nil
-local all_ships, drone_control1, drone_control2, drone_group1, drone_group2, hacking_center, main_boss -- Non-persistent state
+local all_ships, drone_control1, drone_control2, drone_group1, drone_group2, hacking_centre, main_boss -- Non-persistent state
 
 
 function create ()
@@ -197,10 +197,12 @@ function enter ()
    pilot.clear()
    pilot.toggleSpawn(false)
 
+   local wp=mainsys:waypoints()
+
    -- Main positions
-   local pos_drone_control1 = vec2.new( -500, 2000 )
-   local pos_drone_control2 = vec2.new( 18500, 9200 )
-   local pos_hacking_center = vec2.new( 5000, -17000 )
+   local pos_drone_control1 = wp["pirate5_drone_control1"]
+   local pos_drone_control2 = wp["pirate5_drone_control2"]
+   local pos_hacking_centre = wp["pirate5_hacking_centre"]
 
    -- Define the routes
    local route0 = {
@@ -213,7 +215,7 @@ function enter ()
    }
    local route2 = {
       pos_drone_control1,
-      pos_hacking_center,
+      pos_hacking_centre,
    }
    local route3 = {
       pos_drone_control2,
@@ -221,24 +223,24 @@ function enter ()
    }
    local route4 = {
       pos_drone_control2,
-      pos_hacking_center,
+      pos_hacking_centre,
    }
    local route5 = {
-      vec2.new( -5000, 8000 ),
-      vec2.new( -9000, -5000 ),
-      vec2.new( 0, -15000 ),
-      vec2.new( -9000, -5000 ),
+      wp["pirate5_5_1"],
+      wp["pirate5_5_2"],
+      wp["pirate5_5_3"],
+      wp["pirate5_5_4"],
    }
    local route6 = {
-      vec2.new( -4000, -7400 ),
-      vec2.new( 7500, -5000 ),
-      vec2.new( 15000, -7500 ),
-      vec2.new( 7500, -5000 ),
+      wp["pirate5_6_1"],
+      wp["pirate5_6_2"],
+      wp["pirate5_6_3"],
+      wp["pirate5_6_4"],
    }
    local route7 = {
-      vec2.new( -7000, -7000 ),
-      vec2.new( 11000, -5000 ),
-      pos_hacking_center,
+      wp["pirate5_7_1"],
+      wp["pirate5_7_2"],
+      pos_hacking_centre,
    }
 
    -- We'll use a dynamic faction for some ships to lower faction standing damage
@@ -288,10 +290,10 @@ function enter ()
    drone_control2 = spawn_drone_controller( pos_drone_control2 )
    hook.pilot( drone_control2, "death", "drone_control2_dead" )
    hook.pilot( drone_control2, "board", "plant_explosives" )
-   hacking_center = spawn_drone_controller( pos_hacking_center )
-   hacking_center:rename(_("Hacking Centre"))
-   hook.pilot( hacking_center, "death", "hacking_center_dead" )
-   hook.pilot( hacking_center, "board", "plant_explosives" )
+   hacking_centre = spawn_drone_controller( pos_hacking_centre )
+   hacking_centre:rename(_("Hacking Centre"))
+   hook.pilot( hacking_centre, "death", "hacking_centre_dead" )
+   hook.pilot( hacking_centre, "board", "plant_explosives" )
 
    local function add_patrol_group( route, ships, group, start )
       start = start or rnd.rnd(1,#route)
@@ -332,7 +334,7 @@ function enter ()
    end
 
    -- Main boss, isn't necessary to kill
-   local bosspos = pos_hacking_center - vec2.new( -67, -109 )
+   local bosspos = pos_hacking_centre - vec2.new( -67, -109 )
    main_boss = pilot.add( "Za'lek Mephisto", "Za'lek", bosspos, nil, {naked=true, ai="guard"} )
    all_ships[1] = main_boss
    -- Be nice and give only close-range weapons
@@ -395,11 +397,11 @@ function enter ()
 end
 
 function message_first ()
-   hacking_center:broadcast( fmt.f(_("Due to military exercises, {sys} is under lockdown. Please evacuate the area immediately."), {sys=mainsys}), true )
+   hacking_centre:broadcast( fmt.f(_("Due to military exercises, {sys} is under lockdown. Please evacuate the area immediately."), {sys=mainsys}), true )
 end
 
 function message_warn ()
-   hacking_center:broadcast( _("Unwelcome ships will be terminated. You have been warned."), true )
+   hacking_centre:broadcast( _("Unwelcome ships will be terminated. You have been warned."), true )
 end
 
 function message_hostile ()
@@ -445,10 +447,10 @@ function drone_control_update ()
    -- Move the boss a bit away
    if main_boss and main_boss:exists() then
       local aimem = main_boss:memory()
-      aimem.guardpos = vec2.new( 4000, -14000 )
+      aimem.guardpos = mainsys:waypoints("pirate5_guard")
    end
 end
-function hacking_center_dead ()
+function hacking_centre_dead ()
    misn.markerMove( mem.mrk_mainsys, spob.get("Minerva Station") )
    misn.osdActive(3)
    mem.misn_state = 3
