@@ -24,15 +24,16 @@ local der = require 'common.derelict'
 local audio = require 'love.audio'
 local luaspfx = require "luaspfx"
 local love_shaders = require "love_shaders"
+local lmisn = require "lmisn"
 
-local cat_image = "blackcat.webp"
+local cat_image = "blackcat"
 local cat_colour = nil
 
 local owner_image = vni.generic()
 local owner_colour = nil
 local owner -- Non-persistent state
 
-local meow = audio.newSource( "snd/sounds/meow.ogg" )
+local meow = audio.newSoundData( "snd/sounds/meow" )
 
 local credit_reward = 200e3
 
@@ -45,7 +46,7 @@ function create ()
    vn.music( der.sfx.ambient )
    local cat = vn.Character.new( _("Black Cat"), {image=cat_image, colour=cat_colour} )
    vn.transition()
-   vn.na(_([[You make your way through the derelict, each step you take resonating throughout the vacuous vessel. As your traverse a hallway you notice a peculiar texture on one of the walls. As your light illuminates the wall, you can make out a hastily written graffiti. Although it is hard to read, you can make out the following text "#rBEW-RE OF C-T#0". What could it mean?]]))
+   vn.na(_([[You make your way through the derelict, each step you take resonating throughout the vacuous vessel. As your traverse a hallway you notice a peculiar texture on one of the walls. As your light illuminates the wall, you can make out hastily written graffiti. Although it is hard to read, you can make out the following text "#rBEW-RE OF C-T#0". What could it mean?]]))
    vn.na(_([[You eventually reach the command room when your ship suddenly informs you that there is a life form present on the ship. Not only that, it's very close! You frantically ready for a fight and prepare for the worst…
 
 It's right on top of you!]]))
@@ -108,24 +109,12 @@ It seems like it wants to come back with you. What do you do?]]))
    hook.jumpin("jumpin")
 end
 
-local function islucky ()
-   local pp = player.pilot()
-   if pp:ship():tags().lucky then
-      return true
-   end
-   for k,o in ipairs(pp:outfitsList("all")) do
-      if o:tags().lucky then
-         return true
-      end
-   end
-   return false
-end
-
 local event_list = {
+   --[[
    function () -- Overheat
       local pp = player.pilot()
       luaspfx.sfx( false, nil, meow )
-      if islucky() then
+      if lmisn.is_lucky() then
          player.msg(_("Black cat hair has clogged the radiators but burns up before overheating the ship."), true)
          return
       end
@@ -134,12 +123,13 @@ local event_list = {
       player.msg(_("Black cat hair has clogged the radiators and overheated the ship!"), true)
       player.autonavReset()
    end,
+   --]]
    function () -- Temporarily disable
       local pp = player.pilot()
       local dis = pp:disabled()
       if dis then return end -- Already disabled
       luaspfx.sfx( false, nil, meow )
-      if islucky() then
+      if lmisn.is_lucky() then
          player.msg(_("The black cat accidentally hit the ship restart button, but nothing happens."), true)
          return
       end
@@ -151,8 +141,8 @@ local event_list = {
    function () -- Energy discharge
       local pp = player.pilot()
       luaspfx.sfx( false, nil, meow )
-      if islucky() then
-         player.msg(_("The black cat managed to accidentally disconnect the energy capacitors, but the back up system takes over while you fix it."), true)
+      if lmisn.is_lucky() then
+         player.msg(_("The black cat managed to accidentally disconnect the energy capacitors, but the back-up system takes over while you fix it."), true)
          return
       end
       pp:setEnergy( 0 )
@@ -301,9 +291,9 @@ function owner_board ()
    vn.na(_("You scour the ship and end up going back to the commander chair. As you are about to look behind it, you hear a sonorous meow and a black shadow flies past you towards the airlock."))
    vn.sfx( der.sfx.unboard )
    vn.na(_("You run to try to catch it, but hear the sound of the airlock closing and detaching of the locking clamps. You run back to your command chair to see what the other ship is doing, but you can not find it anywhere. They seem to have a knack for fleeing."))
-   vn.na(fmt.f(_("You sit resigned and outwitted at your command chair when you notice a credit chip with {credits} on the floor. It looks like it has cat bite marks too."),{credits=fmt.credits(credit_reward)}))
+   vn.na(fmt.f(_("You sit resigned and outwitted at your command chair when you notice a credit chip with {credits} on the floor. It looks like it has cat bite marks too."),{credits="#g"..fmt.credits(credit_reward).."#0"}))
    vn.sfxVictory()
-   vn.na(_("You then get around to cleaning up the copious amounts of cat hair invading every last corner of your ship. With the amount collected you make a cute black cat doll. It's like a tiny version of the real thing without the assholiness."))
+   vn.na(_("You then get around to cleaning up the copious amounts of cat hair invading every last corner of your ship. With the amount collected you make a cute black cat doll. It's like a tiny version of the real thing without the assholeness."))
    vn.run()
 
    player.pay( credit_reward )
