@@ -32,9 +32,9 @@ local base, basesys = spob.getS("One-Wing Goddard")
 local firstsys = system.get("Bastion")
 local fightsys = system.get("Gamel")
 local lastsys = system.get("Haven")
-local firstpos = vec2.new( -2500, -2000 )
-local fightpos = vec2.new( -2000, 3000 )
-local corpsepos = vec2.new( 11e3, 5e3 )
+local firstpos = firstsys:waypoints("taiomi05_firstpos")
+local fightpos = fightsys:waypoints("taiomi05_fightpos")
+local corpsepos = lastsys:waypoints("taiomi05_corpse")
 local DIST_THRESHOLD = 2000 -- Distance in units
 local BROADCAST_LENGTH = 150 -- Length in seconds
 local SPAWNLIST_FIRST = {
@@ -59,9 +59,9 @@ local SPAWNLIST_FIGHT = {
    0: mission started
    1: landed on one-winged goddard
    2: first broadcast
-   3: finish defense
+   3: finish defence
    4: second broadcast
-   5: finish second defense
+   5: finish second defence
    6: return time
 --]]
 mem.state = 0
@@ -145,7 +145,9 @@ function scavenger_hail ( p )
 end
 
 function scavenger_death ()
-   lmisn.fail(_("Scavenger died! You were supposed to protect them!"))
+   if mem.state < 6 then
+      lmisn.fail(_("Scavenger died! You were supposed to protect them!"))
+   end
 end
 
 function scavenger_attacked( _p, attacker )
@@ -316,7 +318,7 @@ function corpse00 ()
 
    vn.clear()
    vn.scene()
-   vn.music( "snd/sounds/songs/sad_drama.ogg" )
+   vn.music( "snd/sounds/songs/sad_drama" )
    local s = vn.newCharacter( taiomi.vn_scavenger() )
    vn.transition( taiomi.scavenger.transition )
 
@@ -379,7 +381,6 @@ function corpse99 ()
    misn.markerMove( mem.marker, base )
 
    scavenger:effectAdd( "Fade-Out" )
-
    mem.state = 6
 end
 
@@ -476,7 +477,7 @@ function land ()
       vn.disappear( sai, tut.shipai.transition )
 
       vn.appear( {p,w} )
-      vn.music( "snd/sounds/songs/sad_drama.ogg" ) -- TODO necessary?
+      vn.music( "snd/sounds/songs/sad_drama" ) -- TODO necessary?
       vn.na(_("You hear the squeal of metal rubbing on metal as Elder and Philosopher make their way haphazardly through the ship. They get close to you until they fill your entire field of vision."))
       w(_([[After what seems an eternity, Elder begins to broadcast slow and solemnly over an audio channel.
 "It seems like Scavenger has not returned."]]))
