@@ -67,7 +67,11 @@ They stare at you for a few seconds.
          end
          vn.jump("noname")
       end )
-   end )
+   end, {
+      blacklist = {
+         ["\n"] = true, -- Mess up formatting
+      },
+   })
    vn.label("specialname")
    sai( function () return tut.specialnames[ string.upper(ainame) ] end )
 
@@ -138,7 +142,7 @@ They stare at you for a few seconds.
    misn.osdCreate( _("Tutorial"), {
       fmt.f(_("Fly to {startpnt} in the {sys} system with the movement keys"),posd),
       fmt.f(_("Land on {startpnt} in the {sys} system by double-clicking on it"),posd),
-      fmt.f(_("Go to {destpnt} in the {sys} system by right-clicking it on the overview map"),posd),
+      fmt.f(_("Go to {destpnt} in the {sys} system by double-clicking it on the overview map"),posd),
       fmt.f(_("Destroy the practice drone near {destpnt} in the {sys} system"),posd),
       _("Jump to a nearby system by using your starmap"),
    } )
@@ -190,8 +194,8 @@ function timer ()
       sai(_([["Great job! As you can see, by using your ship's Autonav features, the perceived duration of your trip was cut substantially. You will grow to appreciate this feature of your ship in time, especially as you travel from system to system delivering goods and such, given the vastness of space."]]))
       sai(_([["I hope you noticed some of the features of the overview map when you had it activated. Not only are objects such as planets, ships, and asteroids visible on the overview map, but faction #opatrol routes#0 are also shown with thick lines. These routes denote areas that are commonly patrolled and used by ships. Sticking to these routes is generally the best way to travel around, but they don't guarantee your safety. When starting out it is probably best to not stray too far."]]))
       sai(_([["Let's now practice combat. You won't need this if you stick to the safe systems in the Empire core, but sadly, we are likely to encounter hostile ships if you venture further out, so you need to know how to defend yourself. Fortunately, your ship comes pre-equipped with a state-of-the-art laser cannon for just that reason! If all goes well you won't end up a hood ornament like my late previous owner after encountering…  Anyway, on to the drone."]]))
-      sai(fmt.f(_([["I will launch a combat practice drone off of {pnt} now for you to fight. Don't worry; our drone does not have any weapons and will not harm you. Target the drone by clicking on it or by pressing {targethostilekey}, then use your weapons, controlled with {primarykey} and {secondarykey}, to take out the drone!"
-"Ah, yes, one more tip before I launch the drone: if your weapons start losing their accuracy, it's because they're becoming overheated. You can remedy that by pressing {cooldownkey} or double tapping {reversekey} to engage active cooling."]]),{pnt=dest_planet, targethostilekey=tut.getKey("target_hostile"), primarykey=tut.getKey("primary"), secondarykey=tut.getKey("secondary"), cooldownkey=tut.getKey("cooldown"), reversekey=tut.getKey("reverse")}))
+      sai(fmt.f(_([["I will launch a combat practice drone off of {pnt} now for you to fight. Don't worry; our drone does not have any weapons and will not harm you. Target the drone by clicking on it or by pressing {targethostilekey}, then use your weapons, controlled with {primarykey} and {secondarykey}, to take out the drone!"]]),
+         {pnt=dest_planet, targethostilekey=tut.getKey("target_hostile"), primarykey=tut.getKey("primary"), secondarykey=tut.getKey("secondary")}))
       sai(_([["The Drone's AI has been said to be a bit odd, but pay no attention to it. Being an artificial intelligence it is unable to process emotions. Not like me, ha ha. HUMOUR PROCEDURE TERMINATED"]]))
       vn.done( tut.shipai.transition )
       vn.run()
@@ -251,8 +255,8 @@ end
 function land_outfits ()
    hook.rm(mem.outfits_hook)
    mem.outfits_hook = nil
-   msg_info{_([["This is the Outfitter, where you can buy new outfits to make your starship even better! You can fit your ship with new weapons, extra cargo space, more powerful core systems, and more! Regional maps which can help you explore the galaxy more easily can also be purchased here, as well as licenses required for higher-end weaponry and starships. For example, you will require a Large Civilian Vessel License to purchase a Melendez Corporation Mule Bulk Cargo Starship. As my previous owner found out, they don't do too well in combat, though."]]),
-   _([["As you can see, a series of tabs at the top of your screen allow you to filter outfits by type: 'W' for weapons, 'U' for utilities, 'S' for structurals, 'Core' for cores, and 'Other' for anything outside those categories, most notably, regional maps and licenses. When you see an outfit that interests you, click on it to get more information about it, then either click on the '#bBuy#0' button to buy it or click on the '#bSell#0' button to sell it if you have one in your possession. Different planets have different outfits available; if you don't see a specific outfit you're looking for, you can search for it via the '#bFind Outfits#0' button on the starmap screen. After buying new outfits make sure to equip them in the #oEquipment#0 window."]]),
+   msg_info{_([["This is the Outfitter, where you can buy new outfits to make your starship even better! You can fit your ship with new weapons, extra cargo space, more powerful core systems, and more! Regional maps which can help you explore the galaxy more easily can also be purchased here, as well as licences required for higher-end weaponry and starships. For example, you will require a Large Civilian Vessel Licence to purchase a Melendez Corporation Mule Bulk Cargo Starship. As my previous owner found out, they don't do too well in combat, though."]]),
+   _([["As you can see, a series of tabs at the top of your screen allow you to filter outfits by type. When you see an outfit that interests you, click on it to get more information about it, then either click on the '#bBuy#0' button to buy it or click on the '#bSell#0' button to sell it if you have one in your possession. Different planets have different outfits available; if you don't see a specific outfit you're looking for, you can search for it via the '#bFind Outfits#0' button on the starmap screen. After buying new outfits make sure to equip them in the #oEquipment#0 window."]]),
    }
 end
 
@@ -260,7 +264,7 @@ function land_shipyard ()
    hook.rm(mem.shipyard_hook)
    mem.shipyard_hook = nil
    msg_info{_([["This is the Shipyard, where you can buy new starships to either replace the one you've got, or to add to your collection! On the left of this screen, you will see ships available on the planet you're on. Click on a ship you're interested in learning more about. You can then either buy the ship with the '#bBuy#0' button, or trade your current ship in for the new ship with the '#bTrade-In#0' button. Different planets have different ships available; if you don't see a specific ship you're looking for, you can search for it via the '#bFind#0' button on the starmap screen."]]),
-   _([["You likely don't have enough credits for a new ship now, but later on, when you've saved up enough, you'll probably want to upgrade your ship to an even better one, depending on what kinds of tasks you will be performing. Different ships have different strengths and weaknesses which interact with the different outfits you can equip them with. Note that some ships also require licenses before you can buy them."]])
+   _([["You likely don't have enough credits for a new ship now, but later on, when you've saved up enough, you'll probably want to upgrade your ship to an even better one, depending on what kinds of tasks you will be performing. Different ships have different strengths and weaknesses which interact with the different outfits you can equip them with. Note that some ships also require licences before you can buy them."]])
    }
 end
 
@@ -268,8 +272,8 @@ function land_equipment ()
    hook.rm(mem.equipment_hook)
    mem.equipment_hook = nil
    -- TODO cut up
-   msg_info{_([["This is the Equipment screen. Here, you can equip your ship with any outfits you have bought at the #oOutfitter#0. If and only if the current planet has a shipyard, you can also do so with any other ship you own, and you can swap which ship you are currently piloting by selecting another ship and clicking the '#bSwap Ship#0' button or #bdouble-clicking#0 on it. You can also sell those other ships, but not your current ship, with the '#bSell Ship#0' button, if you decide that you no longer need them. Selling a ship that still has outfits equipped will also lead to those outfits being sold along with the ship, so do keep that in mind if there's an outfit you need to keep."]]),
-   _([["If you make any changes to your ship now, please ensure that you still have weapons equipped, as you will need those later for practicing combat, and anyway flying around space without any weapons can be very risky."]]),
+   msg_info{_([["This is the Equipment screen. Here, you can equip your ships with any outfits you have bought at the #oOutfitter#0. You can swap which ship you are currently piloting by selecting another ship and clicking the '#bSwap Ship#0' button or #bdouble-clicking#0 on it. You can also sell those other ships, but not your current ship, with the '#bSell Ship#0' button, if you decide that you no longer need them. Selling a ship that still has outfits equipped will also lead to those outfits being sold along with the ship, so do keep that in mind if there's an outfit you need to keep."]]),
+   _([["If you make any changes to your ship now, please ensure that you still have weapons equipped, as you will need those later for practising combat, and anyway flying around space without any weapons can be very risky."]]),
    }
 end
 
@@ -355,9 +359,8 @@ function pilot_death_timer ()
    local sai = vn.newCharacter( tut.vn_shipai() )
    vn.transition( tut.shipai.transition )
    sai(_([["Excellent work taking out that drone! As you may have noticed, shield level regenerates over time, but armour does not. This is not universal, of course; some ships, particularly larger ships, feature advanced armour repair technology. But even then, armour regeneration is usually much slower than shield regeneration."]]))
-   sai(fmt.f(_([["You may have also noticed your heat meters going up and your weapons becoming less accurate as your ship and weapons got hotter. This is normal, but too much heat can make your weapons difficult to use, which is why it is recommended to use active cooling when it is safe to do so. You can engage active cooling by pressing {cooldownkey} or double tapping {reversekey}. Alternatively, you can cool off your ship instantly by landing on any planet or station."]]),{cooldownkey=tut.getKey("cooldown"), reversekey=tut.getKey("reverse")}))
    sai(fmt.f(_([["It is also worth noting that you can configure the way your weapons shoot from the #oInfo#0 screen, which can be accessed by pressing {infokey} or through the button on the top of your screen. The #oInfo#0 screen also lets you view information about your ship, cargo, current missions, and reputation with various factions. You will likely be referencing it often as we explore the galaxy."]]),{infokey=tut.getKey("info")}))
-   sai(fmt.f(_([["I think we should try venturing outside this system. There are many systems in the galaxy; this one is but a tiny sliver of what can be found out there! Travelling through systems is accomplished with jump points. Like planets, you usually need to find these by exploring the area, talking to the locals, or buying maps. Once you have found a jump point, you can use it by #bright-click#0ing on it or using the {jumpkey}."]]),{jumpkey=tut.getKey("jump")}))
+   sai(fmt.f(_([["I think we should try venturing outside this system. There are many systems in the galaxy; this one is but a tiny sliver of what can be found out there! Travelling through systems is accomplished with jump points. Like planets, you usually need to find these by exploring the area, talking to the locals, or buying maps. Once you have found a jump point, you can use it by #bdouble-clicking#0 on it or using the {jumpkey}."]]),{jumpkey=tut.getKey("jump")}))
    sai(fmt.f(_([["But there is an even better way to navigate across systems! By pressing {starmapkey}, you can open your #oStarmap#0. The #oStarmap#0 shows you all the systems you currently know about. Through your #oStarmap#0, you can click on a system and click on the '#bAutonav#0' button to automatically travel to the system! Of course, this only works if you have a known, valid route to get there, but you will find that this method of travel greatly simplifies things."]]),{starmapkey=tut.getKey("starmap")}))
    sai(fmt.f(_([["Why don't you give it a try and jump to the nearby {sys} system? You should see an indicator mark on your map; missions often use these marks to show you where to go next. You will have to make two jumps and may have to do some exploring to find the second jump point. Let's see what you've learned!"]]),{sys=destsys}))
    vn.done( tut.shipai.transition )
@@ -375,12 +378,12 @@ function spawn_captain_tp ()
 
    p:setHealth( 100, 100 )
    p:setEnergy( 100 )
-   p:setTemp( 0 )
    p:setFuel( true )
 
-   p:setHostile()
-   p:setVisplayer()
-   p:setHilight()
+   p:setHostile(true)
+   p:setVisplayer(true)
+   p:setHilight(true)
+   p:setNoBoard(true)
    hook.pilot( p, "death", "pilot_death" )
 
    -- Don't distress just in case
@@ -457,7 +460,7 @@ local tp_taunt_weak = {
    _("Make the bad man go away, mommy!"),
    _("If you don't stop I'll cry!"),
    _("Here I go, filling my cabin up with tears."),
-   _("U- oh it a-pears my te-rs hav- da--age t-e co-mand cons-le."),
+   _("U- oh it a-pears my te-rs hav- da-ag-d t-e co-mand cons-le."), --codespell:ignore
    _("I a- T. Pr-ct---! Y-- w--l fe-r m- na-e --- Bzzzt!"),
 }
 
