@@ -3,6 +3,8 @@ local ecores = require 'equipopt.cores'
 local eoutfits = require 'equipopt.outfits'
 local eparams = require 'equipopt.params'
 
+local function choose_one( t ) return t[ rnd.rnd(1,#t) ] end
+
 local dvaered_outfits = eoutfits.merge{{
    -- Heavy Weapons
    "Railgun", "Repeating Railgun", "Railgun Turret",
@@ -13,25 +15,25 @@ local dvaered_outfits = eoutfits.merge{{
    "TeraCom Fury Launcher", "TeraCom Headhunter Launcher",
    "Enygma Systems Turreted Fury Launcher", "Enygma Systems Turreted Headhunter Launcher",
    -- Small Weapons
-   "Shredder", "Vulcan Gun", "Gauss Gun",
+   "Shredder", "Vulcan Gun", "Gauss Gun", "Turreted Gauss Gun",
    "TeraCom Mace Launcher", "TeraCom Banshee Launcher",
-   -- Point Defense
+   -- Point Defence
    "Dvaered Flare Battery",
-   "Ratchet Point Defense",
+   "Ratchet Point Defence",
    -- Utility
    "Cyclic Combat AI", "Milspec Impacto-Plastic Coating",
-   "Unicorp Scrambler", "Unicorp Light Afterburner",
-   "Sensor Array", "Hellburner", "Emergency Shield Booster",
+   "Unicorp Scrambler", "Milspec Scrambler", "Unicorp Light Afterburner",
+   "Sensor Array", "Emergency Shield Booster", "Unicorp Jammer",
    "Unicorp Medium Afterburner", "Droid Repair Crew",
    -- Heavy Structural
-   "Large Fuel Pod", "Battery III", "Reactor Class III",
-   "Shield Capacitor III", "Nanobond Plating", "Biometal Armour",
+   "Battery III", "Battery IV", "Reactor Class III",
+   "Shield Capacitor III", "Nanobond Plating",
    -- Medium Structural
-   "Medium Fuel Pod", "Battery II", "Shield Capacitor II",
-   "Active Plating", "Reactor Class II",
+   "Battery II", "Shield Capacitor II",
+   "Active Plating", "Microbond Plating", "Reactor Class II",
    -- Small Structural
-   "Plasteel Plating", "Battery I", "Improved Stabilizer", "Engine Reroute",
-   "Reactor Class I", "Small Fuel Pod",
+   "Plasteel Plating", "Battery I", "Improved Stabilizer",
+   "Reactor Class I", "Engine Reroute",
 }}
 
 local dvaered_params = {
@@ -42,6 +44,7 @@ local dvaered_params = {
       } end,
    ["Dvaered Phalanx"] = function () return {
          turret = 1.25,
+         pointdefence = 0.8, -- point defences are turrets so we compensate
          type_range = {
             ["Launcher"] = { max = rnd.rnd(2,3) },
          }
@@ -65,22 +68,36 @@ local dvaered_params = {
 --local function choose_one( t ) return t[ rnd.rnd(1,#t) ] end
 local dvaered_cores = { -- Basically elite hulls excluding stealth
    ["Dvaered Vendetta"] = function () return {
-         "S&K Light Combat Plating",
+         systems = choose_one{ "Milspec Orion 2301 Core System", "Milspec Prometheus 2203 Core System" },
+         systems_secondary = choose_one{ "Milspec Orion 2301 Core System", "Milspec Prometheus 2203 Core System" },
+         hull = "S&K Skirmish Plating",
+         hull_secondary = "S&K Skirmish Plating",
       } end,
    ["Dvaered Ancestor"] = function () return {
-         "S&K Light Combat Plating",
+         systems = choose_one{ "Milspec Orion 2301 Core System", "Milspec Prometheus 2203 Core System" },
+         systems_secondary = choose_one{ "Milspec Orion 2301 Core System", "Milspec Prometheus 2203 Core System" },
+         hull = "S&K Skirmish Plating",
+         hull_secondary = "S&K Skirmish Plating",
       } end,
    ["Dvaered Phalanx"] = function () return {
-         "S&K Medium Combat Plating",
+         systems = choose_one{ "Milspec Orion 4801 Core System", "Milspec Prometheus 4703 Core System" },
+         hull = "S&K Battle Plating",
       } end,
    ["Dvaered Vigilance"] = function () return {
-         "S&K Medium-Heavy Combat Plating",
+         systems = choose_one{ "Milspec Orion 4801 Core System", "Milspec Prometheus 4703 Core System" },
+         systems_secondary = choose_one{ "Milspec Orion 4801 Core System", "Milspec Prometheus 4703 Core System" },
+         hull = "S&K Battle Plating",
+         hull_secondary = "S&K Battle Plating",
       } end,
    ["Dvaered Retribution"] = function () return {
-         "S&K Heavy Combat Plating",
+         systems = choose_one{ "Milspec Orion 8601 Core System", "Milspec Prometheus 8503 Core System" },
+         hull = "S&K War Plating",
       } end,
    ["Dvaered Goddard"] = function () return {
-         "S&K Superheavy Combat Plating",
+         systems = choose_one{ "Milspec Orion 8601 Core System", "Milspec Prometheus 8503 Core System" },
+         systems_secondary = choose_one{ "Milspec Orion 8601 Core System", "Milspec Prometheus 8503 Core System" },
+         hull = "S&K War Plating",
+         hull_secondary = "S&K War Plating",
       } end,
 }
 
@@ -95,7 +112,7 @@ local dvaered_params_overwrite = {
    },
    max_same_stru = 3,
    ew = 0, -- Don't care about electronic warfare
-   min_energy_regen = 1.0, -- Davereds want more energy
+   min_energy_regen = 1.0, -- Dvaereds want more energy
 }
 
 --[[
@@ -132,7 +149,7 @@ local function equip_dvaered( p, opt_params )
       if dvrcor then
          cores = dvrcor()
       else
-         cores = ecores.get( p, { hulls="elite" } )
+         cores = ecores.get( p, { systems="standard", hulls="elite", engines="standard" } )
       end
    end
 
