@@ -10,39 +10,55 @@ Valid parameters:
 local audio = require "love.audio"
 local utf8 = require "utf8"
 local lf = require "love.filesystem"
+local fmt = require "format"
 
 -- List of songs to use
 local takeoff_songs = {}
 local factional_songs = {}
 local spob_songs = {}
+local spob_songs_func = {}
 local system_ambient_songs = {}
-local ambient_songs = {}
+local ambient_songs_func = {}
 local loading_songs = {}
 local intro_songs = {}
 local credits_songs = {}
 local factional_combat_songs = {}
-local combat_songs = {}
-local nebula_combat_songs = {}
+local combat_songs_func = {}
 
-for k,v in ipairs(lf.getDirectoryItems("snd/music")) do
-   local suffix = utf8.sub(v, -4)
-   if suffix=='.lua' then
-      local t = require( "snd.music."..string.gsub(v,".lua","") )
+local function loadsongs ()
+   local modules = {}
+   for k,v in ipairs(lf.getDirectoryItems("snd/music")) do
+      local suffix = utf8.sub(v, -4)
+      if suffix=='.lua' then
+         local t = require( "snd.music."..string.gsub(v,".lua","") )
+         t.priority = t.priority or 5
+         table.insert( modules, t )
+      end
+   end
+   -- We sort from largest to lowest and overwrite
+   table.sort( modules, function( a, b )
+      return a.priority > b.priority
+   end )
+   for k,t in ipairs(modules) do
+      -- Overwrite fields with tmerge
       tmerge( factional_songs, t.factional_songs )
       tmerge( spob_songs, t.spob_songs )
       tmerge( system_ambient_songs, t.system_ambient_songs )
       tmerge( takeoff_songs, t.takeoff_songs )
-      tmerge( ambient_songs, t.ambient_songs )
       tmerge( loading_songs, t.loading_songs )
       tmerge( intro_songs, t.intro_songs )
       tmerge( credits_songs, t.credits_songs )
       tmerge( factional_combat_songs, t.factional_combat_songs )
-      tmerge( combat_songs, t.combat_songs )
-      tmerge( nebula_combat_songs, t.nebula_combat_songs )
+      -- Insert at the front as it should be higher priority
+      table.insert( spob_songs_func, 1, t.spob_songs_func )
+      table.insert( ambient_songs_func, 1, t.ambient_songs_func )
+      table.insert( combat_songs_func, 1, t.combat_songs_func )
    end
 end
+loadsongs()
 
 local last_track -- last played track name
+local last_track_type = {} -- Last track by type
 local tracks = {} -- currently playing tracks (including fading)
 local music_off = false -- disabled picking or changing music
 local music_situation -- current running situation
@@ -58,6 +74,11 @@ local function tracks_stop ()
          v.m:stop()
          table.insert( remove, k )
       end
+      -- Mark when it ended
+      local situ = v.situation
+      if situ and last_track_type[situ].name==v.name then
+         last_track_type[situ].elapsed = v.elapsed
+      end
    end
    for k=#remove, 1, -1 do
       table.remove( tracks, k )
@@ -71,6 +92,7 @@ local function tracks_add( name, situation, params )
    end
    music_situation = situation
    last_track = name
+   last_track_type[music_situation] = { name=name }
 
    local name_orig = name
    if string.sub(name, 1, 1) ~= "/" then
@@ -90,7 +112,13 @@ local function tracks_add( name, situation, params )
       delay = params.delay,
       name  = name_orig,
       elapsed = 0,
+      situation = situation,
    }
+   if params.seek then
+      local seek = math.max( params.seek-1, 0 )
+      m:seek( seek )
+      t.elapsed = seek
+   end
    if not params.delay then
       m:play()
    end
@@ -127,6 +155,19 @@ local function tracks_resume ()
    end
 end
 
+-- Tries to resume the last played song of the sitution if it is in the lost
+local function tracks_resume_last( newlist, situation )
+   local last = last_track_type[situation]
+   if last and last.elapsed and (last.elapsed > 0) and inlist( newlist, last.name ) then
+      tracks_add( last.name, situation, {
+         fade = 1,
+         seek = last.elapsed,
+      } )
+      return true
+   end
+   return false
+end
+
 --[[--
 Play a song if it's not currently playing.
 --]]
@@ -180,7 +221,6 @@ function choose_table.land ()
       return choose_table.ambient()
    end
    local pnt   = spob.cur()
-   local class = pnt:class()
    local music_list
    local params = {
       delay = 0.8,
@@ -205,20 +245,16 @@ function choose_table.land ()
       end
    end
 
-   -- Standard to do it based on type of planet
-   if class == "M" then
-      music_list = { "agriculture.ogg" }
-   elseif class == "O" then
-      music_list = { "ocean.ogg" }
-   elseif class == "P" then
-      music_list = { "snow.ogg" }
-   else
-      if pnt:services()["inhabited"] then
-         music_list = { "cosmostation.ogg", "upbeat.ogg" }
-      else
-         music_list = { "agriculture.ogg" }
+   -- See if some function gives us what we want
+   for k,f in ipairs( spob_songs_func ) do
+      music_list = f( pnt )
+      if music_list ~= nil then
+         break
       end
    end
+   if music_list==nil or #music_list <= 0 then
+      error(fmt.f(_("No compatible music for spob '{spb}'!"), {spb=pnt}))
+   end
 
    tracks_add( music_list[ rnd.rnd(1,#music_list) ], "land", params )
    return true
@@ -254,6 +290,16 @@ local function sys_strongest_faction( sys, combat )
    return strongest
 end
 
+local function neutral_ambient_songs ()
+   for k,f in ipairs( ambient_songs_func ) do
+      local t = f()
+      if t ~= nil then
+         return t
+      end
+   end
+   return {}
+end
+
 -- Save old data
 local last_sysFaction  = nil
 local last_sysNebuDens = nil
@@ -308,32 +354,27 @@ function choose_table.ambient ()
 
    -- Must be forced
    if force then
-      -- Choose the music, bias by faction first
-      local add_neutral = false
-      local neutral_prob = 0.6
-      if strongest ~= nil and factional_songs[strongest] then
-         ambient = factional_songs[strongest]
-         add_neutral = factional_songs[strongest].add_neutral
-      elseif nebu then
-         ambient = { "ambient1.ogg", "ambient3.ogg" }
-         add_neutral = true
-      else
-         ambient = ambient_songs
-      end
 
-      -- Clobber array with generic songs if allowed.
-      if add_neutral and rnd.rnd() < neutral_prob then
-         ambient = ambient_songs
+      -- Choose the music, bias by faction first
+      if strongest ~= nil and factional_songs[strongest] then
+         if factional_songs[strongest].add_neutral and rnd.rnd() < 0.5 then
+            ambient = neutral_ambient_songs()
+         else
+            ambient = factional_songs[strongest]
+         end
+      else
+         ambient = neutral_ambient_songs()
       end
 
       -- Make sure it's not already in the list or that we have to stop the
       -- currently playing song.
-      if track then
-         for k,v in pairs(ambient) do
-            if track.name == v then
-               return false
-            end
-         end
+      if track and inlist( ambient, track.name ) then
+         return false
+      end
+
+      -- See if we should resume the last played ambient song
+      if tracks_resume_last( ambient, "ambient" ) then
+         return true
       end
 
       -- Avoid repetition
@@ -351,6 +392,15 @@ function choose_table.ambient ()
    return false
 end
 
+local function neutral_combat_songs ()
+   for k,f in ipairs( combat_songs_func ) do
+      local t = f()
+      if t ~= nil then
+         return t
+      end
+   end
+   return {}
+end
 
 --[[--
 Chooses battle songs.
@@ -358,37 +408,33 @@ Chooses battle songs.
 function choose_table.combat ()
    -- Get some data about the system
    local sys       = system.cur()
-   local nebu_dens = sys:nebula()
    local combat
 
    local strongest = sys_strongest_faction( sys, true )
 
-   local nebu = nebu_dens > 0
-   if nebu then
-      combat = nebula_combat_songs
-   else
-      combat = combat_songs
-   end
-
    if factional_combat_songs[strongest] then
-      if factional_combat_songs[strongest].add_neutral then
-         for k, v in ipairs( factional_combat_songs[strongest] ) do
-            combat[ #combat + 1 ] = v
-         end
+      if factional_combat_songs[strongest].add_neutral and rnd.rnd() < 0.5 then
+         combat = neutral_combat_songs()
       else
          combat = factional_combat_songs[strongest]
       end
+   else
+      combat = neutral_combat_songs()
+   end
+   if combat==nil or #combat <=0 then
+      error(_("No compatible combat music!"))
    end
 
    -- Make sure it's not already in the list or that we have to stop the
    -- currently playing song.
    local t = tracks_playing()
-   if t then
-      for k,v in pairs(combat) do
-         if t.name == v then
-            return false
-         end
-      end
+   if t and inlist( combat, t.name ) then
+      return false
+   end
+
+   -- See if we should resume the last played combat song
+   if tracks_resume_last( combat, "combat" ) then
+      return true
    end
 
    -- Avoid repetition
@@ -620,3 +666,7 @@ function volume( vol )
       v.m:setVolume( music_vol * v.vol, true )
    end
 end
+
+function reset()
+   music_off = false
+end
